@@ -1,14 +1,27 @@
 //                              -*- Mode: C++ -*-
 // 
-// uC++ Version 4.7, Copyright (C) Martin Karsten 1995
+// uC++ Version 5.0.1, Copyright (C) Martin Karsten 1995
 // 
 // LangBasics.h -- 
 // 
 // Author           : Martin Karsten
 // Created On       : Sat May 13 14:55:53 1995
-// Last Modified By : Martin Karsten
-// Last Modified On : Mon Jun 12 18:30:40 1995
-// Update Count     : 2
+// Last Modified By : Peter A. Buhr
+// Last Modified On : Thu Sep 14 17:00:44 2000
+// Update Count     : 5
+//
+// This  library is free  software; you  can redistribute  it and/or  modify it
+// under the terms of the GNU Lesser General Public License as published by the
+// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
+// option) any later version.
+// 
+// This library is distributed in the  hope that it will be useful, but WITHOUT
+// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
+// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
+// for more details.
+// 
+// You should  have received a  copy of the  GNU Lesser General  Public License
+// along  with this library.
 // 
 
 #ifndef _LangBasics_h_
@@ -70,9 +83,10 @@ inline int operator != ( const KernelThreadDescriptor& x, const KernelThreadDesc
 	return x.id != y.id;
 } // operator !=
 
-#endif /* __U_CPLUSPLUS__ */
+#endif // __U_CPLUSPLUS__
 
-#endif /* _LangBasics_h_ */
+
+#endif // _LangBasics_h_
 
 
 // Local Variables: //
