@@ -1,14 +1,27 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Peter Buhr 1997
+// uC++ Version 5.0.1, Copyright (C) Peter Buhr 1997
 // 
 // uDebuggerProtocolUnit.cc -- 
 // 
 // Author           : Peter Buhr
 // Created On       : Wed Oct 15 13:16:10 1997
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Dec  7 18:09:28 1998
-// Update Count     : 7
+// Last Modified On : Thu Jun 28 16:51:29 2001
+// Update Count     : 10
+//
+// This  library is free  software; you  can redistribute  it and/or  modify it
+// under the terms of the GNU Lesser General Public License as published by the
+// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
+// option) any later version.
+// 
+// This library is distributed in the  hope that it will be useful, but WITHOUT
+// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
+// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
+// for more details.
+// 
+// You should  have received a  copy of the  GNU Lesser General  Public License
+// along  with this library.
 // 
 
 
@@ -157,11 +170,7 @@ void uDebuggerProtocolUnit::createNcreateULThread( ULThreadId ul_thread_id, Clus
 	pdu_data.data.create_ul_thread_data.ul_thread_id = ul_thread_id;
 	pdu_data.data.create_ul_thread_data.cluster_id = cluster_id;
 	pdu_data.data.create_ul_thread_data.reg_set = reg_set;
-#if defined ( __svr4__ )
 	memcpy( pdu_data.data.create_ul_thread_data.name, (char*)name, maxEntityName );
-#else
-	bcopy( (char*)name, pdu_data.data.create_ul_thread_data.name, maxEntityName );
-#endif
 	// just to be sure
 	pdu_data.data.create_ul_thread_data.name[maxEntityName - 1] = '\0';
 	pdu_data.request_type = NcreateULThread;
@@ -174,11 +183,7 @@ void uDebuggerProtocolUnit::createNattachULThread( ULThreadId ul_thread_id, ULTh
 	pdu_data.data.attach_ul_thread_data.ret_thread_id = ret_thread_id;
 	pdu_data.data.attach_ul_thread_data.cluster_id = cluster_id;
 	pdu_data.data.attach_ul_thread_data.reg_set = reg_set;
-#if defined ( __svr4__ )
 	memcpy( pdu_data.data.attach_ul_thread_data.name, (char*)name, maxEntityName );
-#else
-	bcopy( (char*)name, pdu_data.data.attach_ul_thread_data.name, maxEntityName );
-#endif
 	// just to be sure
 	pdu_data.data.attach_ul_thread_data.name[maxEntityName - 1] = '\0';
 	pdu_data.request_type = NattachULThread;
@@ -215,11 +220,7 @@ void uDebuggerProtocolUnit::createNdestroyKernelThread( ULThreadId ul_thread_id,
 void uDebuggerProtocolUnit::createNcreateCluster( ClusterId cluster_id, const char* name, bool copy_from_init ) {
 //													uAssert( pdu_data.request_type == NoType );
 	pdu_data.data.create_cluster_data.cluster_id = cluster_id;
-#if defined ( __svr4__ )
 	memcpy( pdu_data.data.create_cluster_data.name, (char*)name, maxEntityName );
-#else
-	bcopy( (char*)name, pdu_data.data.create_cluster_data.name, maxEntityName );
-#endif
 	// just to be sure
 	pdu_data.data.create_cluster_data.name[maxEntityName - 1] = '\0';
 	pdu_data.data.create_cluster_data.copy_from_init = copy_from_init;
@@ -285,17 +286,9 @@ void uDebuggerProtocolUnit::createOcontULThread( ULThreadId ul_thread_id, char*
 	pdu_data.data.cont_ul_thread_data.ul_thread_id = ul_thread_id;
 	pdu_data.data.cont_ul_thread_data.adjustment = adjustment;
 	if ( bp_mask ) {
-#if defined ( __svr4__ )
 		memcpy( (char*)pdu_data.data.cont_ul_thread_data.bp_mask, (char*)bp_mask, SIZE_OF_BREAKPOINT_FIELD / NBBY );
-#else
-		bcopy( (char*)bp_mask, (char*)pdu_data.data.cont_ul_thread_data.bp_mask, SIZE_OF_BREAKPOINT_FIELD / NBBY );
-#endif
 	} else {
-#if defined ( __svr4__ )
 		memset( (char*)pdu_data.data.cont_ul_thread_data.bp_mask, 0, SIZE_OF_BREAKPOINT_FIELD / NBBY );
-#else
-		bzero( (char*)pdu_data.data.cont_ul_thread_data.bp_mask, SIZE_OF_BREAKPOINT_FIELD / NBBY );
-#endif
 	}
 	pdu_data.request_type = OcontULThread;
 	size = sizeof(contULThreadPDU);
@@ -525,11 +518,7 @@ void uDebuggerProtocolUnit::readOcontULThread( ULThreadId& ul_thread_id, char* b
 													uAssert( pdu_data.request_type == OcontULThread );
 	ul_thread_id = pdu_data.data.cont_ul_thread_data.ul_thread_id;
 	adjustment = pdu_data.data.cont_ul_thread_data.adjustment;
-#if defined ( __svr4__ )
 	memcpy( (char*)bp_mask, (char*)pdu_data.data.cont_ul_thread_data.bp_mask, SIZE_OF_BREAKPOINT_FIELD / NBBY );
-#else
-	bcopy( (char*)pdu_data.data.cont_ul_thread_data.bp_mask, (char*)bp_mask, SIZE_OF_BREAKPOINT_FIELD / NBBY );
-#endif
 }
 
 void uDebuggerProtocolUnit::readOshutdownConnection() {
@@ -623,5 +612,5 @@ void uDebuggerProtocolUnit::readBbpClearCondition (int &bp_no, ULThreadId& ul_th
 
 // Local Variables: //
 // tab-width: 4 //
-// compile-command: "dmake install" //
+// compile-command: "gmake install" //
 // End: //
