@@ -1,30 +1,37 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Martin Karsten 1995
+// uC++ Version 5.0.1, Copyright (C) Martin Karsten 1995
 // 
 // uDebuggerProtocolUnit.h -- 
 // 
 // Author           : Martin Karsten
 // Created On       : Thu Apr 20 21:36:45 1995
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Jun  1 18:05:43 1999
-// Update Count     : 50
+// Last Modified On : Tue Dec  9 15:03:33 2003
+// Update Count     : 55
+//
+// This  library is free  software; you  can redistribute  it and/or  modify it
+// under the terms of the GNU Lesser General Public License as published by the
+// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
+// option) any later version.
+// 
+// This library is distributed in the  hope that it will be useful, but WITHOUT
+// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
+// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
+// for more details.
+// 
+// You should  have received a  copy of the  GNU Lesser General  Public License
+// along  with this library.
 // 
 
 
 #ifndef _uDebuggerProtocolUnit_h_
 #define _uDebuggerProtocolUnit_h_ 1
 
-#include <uAssert.h>
 
 #include "LangBasics.h"
 #include "ArchBasics.h"
 
-// otherwise, the stuff is declared in ArchBasics.h
-#if defined( __svr4__ )
-#include <string.h>
-#endif
-
 #ifndef NBBY
 #define NBBY 8
 #endif
@@ -347,10 +354,10 @@ public:
 }; // class uDebuggerProtocolUnit
 
 
-#endif /* _uDebuggerProtocolUnit_h_ */
+#endif // _uDebuggerProtocolUnit_h_
 
 
 // Local Variables: //
 // tab-width: 4 //
-// compile-command: "dmake install" //
+// compile-command: "gmake install" //
 // End: //
