@@ -1,14 +1,27 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Martin Karsten 1995
+// uC++ Version 5.0.1, Copyright (C) Martin Karsten 1995
 // 
 // uLocalDebugger.cc -- 
 // 
 // Author           : Martin Karsten
 // Created On       : Thu Apr 20 21:34:48 1995
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Jun  1 21:55:44 1999
-// Update Count     : 619
+// Last Modified On : Thu Aug 12 08:32:21 2004
+// Update Count     : 674
+//
+// This  library is free  software; you  can redistribute  it and/or  modify it
+// under the terms of the GNU Lesser General Public License as published by the
+// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
+// option) any later version.
+// 
+// This library is distributed in the  hope that it will be useful, but WITHOUT
+// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
+// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
+// for more details.
+// 
+// You should  have received a  copy of the  GNU Lesser General  Public License
+// along  with this library.
 // 
 
 
@@ -22,11 +35,8 @@
 
 #include <uLocalDebugger.h>
 
-#include <stdio.h>										// FILENAME_MAX
-#include <signal.h>
-#include <unistd.h>										// prototype: getcwd
-#include <string.h>										// prototype: strcat
-#include <sys/param.h>									// MAXHOSTNAMELEN on BSD
+#include <csignal>
+#include <unistd.h>										// gethostname
 
 #include <uDebuggerProtocolUnit.h>						// must come after param.h
 #include <uBConditionEval.h>
@@ -35,24 +45,6 @@
 #define FILENAME_MAX 1024
 #endif
 
-#if ! defined( __svr4__ ) && defined( __sun__ )
-extern "C" int sigpause( int );							// missing from signal.h
-extern "C" char *getwd( char[] );
-#endif
-
-#if defined( __sgi__ )
-extern "C" void bzero( void *, int );					// for FD_ZERO
-#endif
-
-#if defined( __aix__ ) && defined( __ibm__ )
-extern "C" int sigpause( int );							// missing from signal.h
-#endif
-
-#if defined( __ultrix__ ) && defined( __dec__ )
-extern "C" int sigpause( int );							// missing from signal.h
-#endif
-
-
 // for the moment...
 #ifndef SIZE_OF_BREAKPOINT_FIELD
 #define SIZE_OF_BREAKPOINT_FIELD	64
@@ -62,14 +54,14 @@ static const int max_no_of_breakpoints = SIZE_OF_BREAKPOINT_FIELD;
 
 bool uLocalDebugger::uGlobalDebuggerActive = false;
 bool uLocalDebugger::uLocalDebuggerActive = false;
-uLocalDebugger *uLocalDebugger::uLocalDebuggerInstance = (uLocalDebugger *)0;
+uLocalDebugger *uLocalDebugger::uLocalDebuggerInstance = NULL;
 bool uLocalDebugger::abort_confirmed = false;
 
 // KEEP CONSISTENT WITH THE CORRESPONDING FUNCTIONS IN uC++.h
 // REASON : ACHIEVE OPTIMIZATION WITHOUT TURNING ON THE COMPILER'S
 // OPTIMIZATION FLAG (-O) TO MAKE INLINE FUNCTIONS REALLY INLINE
-#define U_THIS_TASK		uKernelModule::uActiveTask		// uThisTask()
-#define U_THIS_CLUSTER	uKernelModule::uActiveCluster	// uThisCluster()
+#define U_THIS_TASK		THREAD_GETMEM( uActiveTask)		// uThisTask()
+#define U_THIS_CLUSTER	THREAD_GETMEM( uActiveCluster)	// uThisCluster()
 
 // include now, so that everything is already declared
 #include <uLocalDebuggerHandler.h>
@@ -78,10 +70,10 @@ bool uLocalDebugger::abort_confirmed = false;
 void uLocalDebugger::uLocalDebuggerBeginCode() {}		// marker beginning of debugger code
 
 
-static void readPDU( uSocketClient &sockClient, uDebuggerProtocolUnit &pdu ) {
+void uLocalDebugger::readPDU( uSocketClient &sockClient, uDebuggerProtocolUnit &pdu ) {
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d readPDU, called by task:0x%p\n", __LINE__, &uThisTask() );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
 	uDebuggerProtocolUnit::RequestType request_type;
 
@@ -94,7 +86,7 @@ static void readPDU( uSocketClient &sockClient, uDebuggerProtocolUnit &pdu ) {
 	pdu.re_init( request_type );
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d uLocalDebugger/readPDU : got request %d\n", __LINE__, request_type );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 	if ( pdu.data_size() ) {
 		if ( sockClient.read( (char *)pdu.data_buffer(), pdu.data_size() ) != pdu.data_size() ) {
 			uLocalDebugger::uGlobalDebuggerActive = false;
@@ -105,8 +97,8 @@ static void readPDU( uSocketClient &sockClient, uDebuggerProtocolUnit &pdu ) {
 
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d readPDU, done\n", __LINE__ );
-#endif /* __U_DEBUG_H__ */
-} // readPDU
+#endif // __U_DEBUG_H__
+} // uLocalDebugger::readPDU
 
 
 //######################### uLocalDebuggerReader #########################
@@ -127,18 +119,19 @@ uTask uLocalDebuggerReader {
     ~uLocalDebuggerReader();
 }; // uLocalDebuggerReader
 
+extern "C" void uDebugPrt( const char fmt[], ... );
 
 void uLocalDebuggerReader::main() {
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d (uLocalDebuggerReader &)0x%p.main, starts\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
 	uCluster *cluster;
 	uProcessor *processor;
 	bool ignore;
 
-	for ( ;; ) {
-		readPDU( sockClient, pdu );					// read next pdu
+  end: for ( ;; ) {
+		uLocalDebugger::readPDU( sockClient, pdu );		// read next pdu
 
 		switch( pdu.getType() ) {
 		  case uDebuggerProtocolUnit::AreplyAddress:
@@ -150,23 +143,29 @@ void uLocalDebuggerReader::main() {
 			debugger.finish();
 #ifdef __U_DEBUG_H__
 			uDebugPrt( "%d (uLocalDebuggerReader &)0x%p.main, saw OshutdownConnection\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 			break;
 		  case uDebuggerProtocolUnit::CfinishLocalDebugger:
 #ifdef __U_DEBUG_H__
 			uDebugPrt( "%d (uLocalDebuggerReader &)0x%p.main, saw CfinishLocalDebugger, bye\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
-	return;
+#endif // __U_DEBUG_H__
+			break end;
 		  case uDebuggerProtocolUnit::OstartAtomicOperation:
 			debugger.performAtomicOperation();
 			break;
 		  case uDebuggerProtocolUnit::OignoreClusterMigration:
 			pdu.readOignoreClusterMigration( cluster, ignore );
+#ifdef __U_DEBUG_H__
+#endif // __U_DEBUG_H__
+			uDebugPrt( "%d (uLocalDebuggerReader &)0x%p.main, saw OignoreClusterMigration, cluster:0x%p, ignore:%d\n", __LINE__, this, cluster, ignore );
 			cluster->uDebugIgnore = ignore;
 			break;
 		  case uDebuggerProtocolUnit::OignoreKernelThreadMigration:
 			pdu.readOignoreKernelThreadMigration( processor, ignore );
-			cluster->uDebugIgnore = ignore;
+#ifdef __U_DEBUG_H__
+#endif // __U_DEBUG_H__
+			uDebugPrt( "%d (uLocalDebuggerReader &)0x%p.main, saw OignoreKernelThreadMigration, processor:0x%p, ignore:%d\n", __LINE__, this, processor, ignore );
+			processor->uDebugIgnore = ignore;
 			break;
 		  case uDebuggerProtocolUnit::BbpMarkCondition:
 			{
@@ -176,7 +175,7 @@ void uLocalDebuggerReader::main() {
 				debugger.setConditionMask( bp_no, ul_thread_id );
 #ifdef __U_DEBUG_H__
 				uDebugPrt( "%d (uLocalDebuggerReader &)0x%p.main, read BbpMarkCondition %d\n", __LINE__, this, bp_no );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 				break;
 			}
 		  case uDebuggerProtocolUnit::BbpClearCondition:
@@ -187,7 +186,7 @@ void uLocalDebuggerReader::main() {
 				debugger.resetConditionMask( bp_no, ul_thread_id );
 #ifdef __U_DEBUG_H__
 				uDebugPrt( "%d (uLocalDebuggerReader &)0x%p.main, read BbpClearCondition %d\n", __LINE__, this, bp_no );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 				break;
 			}
 		  default:
@@ -213,18 +212,14 @@ uLocalDebuggerReader::~uLocalDebuggerReader() {
 void uLocalDebugger::main() {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.main, starts\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
 	if ( ! attaching ) {
 		char fullpath[FILENAME_MAX];
 		if ( name[0] == '/' ) {
 			fullpath[0] = 0;
 		} else {
-#if defined( __sun__ ) && ! defined( __svr4__ )
-			if ( ! getwd( fullpath ) ) {
-#else
 			if ( ! getcwd( fullpath, FILENAME_MAX - (strlen(name) + 1) ) ) {
-#endif
 				uAbort( "(uLocalDebugger &)0x%p.main: unable to obtain full pathname", this );
 			} // if
 			strcat( fullpath, "/" );
@@ -233,9 +228,8 @@ void uLocalDebugger::main() {
 		uCreateLocalDebugger( port, machine, fullpath );
 	} else {
 		char machine[MAXHOSTNAMELEN + 1];
-		if ( uGethostname(machine, MAXHOSTNAMELEN + 1) ) {
-			// TEMPORARY: uAbort is a little harsh
-			uAbort ( "could not get hostname, attach failed." );
+		if ( gethostname( machine, MAXHOSTNAMELEN + 1 ) == -1 ) {
+			uAbort ( "could not get hostname, attach failed." ); // TEMPORARY: uAbort is a little harsh
 		} // if
 		char *name = uDefAttachName;
 
@@ -249,12 +243,12 @@ void uLocalDebugger::main() {
 
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d (uLocalDebugger &)0x%p.main, port:%d, machine:0x%p, name:0x%p\n", __LINE__, this, port, machine, name );
-#endif __U_DEBUG_H__
+#endif // __U_DEBUG_H__
 
 	for ( ;; ) {
 #ifdef __U_DEBUG_H__
 		uDebugPrt( "%d (uLocalDebugger &)0x%p.main, loop\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 		uAccept( ~uLocalDebugger ) {
 			break;
 		} uOr uAccept( breakpointHandler ) {
@@ -305,7 +299,7 @@ void uLocalDebugger::main() {
 
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.main, done\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 } // uLocalDebugger::main
 
 
@@ -329,7 +323,7 @@ void uLocalDebugger::resetConditionMask( int bp_no, void *ul_thread_id ) {
 void uLocalDebugger::deregister() {
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d (uLocalDebugger &)0x%p.deregister, called\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
   if ( ! uLocalDebuggerActive ) return;
 
@@ -356,16 +350,16 @@ void uLocalDebugger::deregister() {
 void uLocalDebugger::uCreateLocalDebugger( int port, char *machine, char *name ) {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.uCreateLocalDebugger, on its way...\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
-	sockClient = new uSocketClient( port, machine, *uKernelModule::uSystemCluster );	// create the socket client
+	sockClient = new uSocketClient( port, machine );	// create the socket client
 	uGlobalDebuggerActive = true;						// global debugger has connected to socket
 
 	// Turn on local debugger requests only after the socket is created.
 
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.uCreateLocalDebugger, sending init data : max_no_of_breakpoints %d\n", __LINE__, this, max_no_of_breakpoints );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
 	int length = strlen( name ) + 1;
 	pdu.createNinitLocalDebugger( max_no_of_breakpoints, length );
@@ -384,7 +378,7 @@ void uLocalDebugger::uCreateLocalDebugger( int port, char *machine, char *name )
     // CODE FOR TASKS CANNOT BE FOUND. IT NEEDS FIXING.
 
 	uKernelModule::uSystemProcessor->uDebugIgnore = false;
-#endif __U_MULTI__
+#endif // __U_MULTI__
 
 	// now start the dispatcher task
 	dispatcher = new uLocalDebuggerReader( *this, *sockClient );
@@ -393,55 +387,51 @@ void uLocalDebugger::uCreateLocalDebugger( int port, char *machine, char *name )
 	uSeqGen<uClusterDL> ci;
 	uClusterDL *cr;
 	for ( ci.uOver( *uKernelModule::uGlobalClusters ); ci >> cr; ) {
-		uCluster *cluster = &cr->uGet();
+		uCluster &cluster = cr->uGet();
 #ifdef __U_DEBUG_H__
-		uDebugPrt( "%d (uLocalDebugger &)0x%p.uCreateLocalDebugger, cluster is %s (0x%p)\n", __LINE__, this, cluster->uGetName(), cluster );
-#endif /* __U_DEBUG_H__ */
-		createCluster( *cluster );
+		uDebugPrt( "%d (uLocalDebugger &)0x%p.uCreateLocalDebugger, cluster is %s (0x%p)\n", __LINE__, this, cluster.uGetName(), &cluster );
+#endif // __U_DEBUG_H__
+		createCluster( cluster );
 		send( pdu );
 
 		// register processors associated with this cluster
 		uProcessorDL *pr;
-		for ( uSeqGen<uProcessorDL> gen( cluster->uProcessorsOnCluster ); gen >> pr; ) {
-			uProcessor *processor = &pr->uGet();
+		for ( uSeqGen<uProcessorDL> gen( cluster.uProcessorsOnCluster ); gen >> pr; ) {
+			uProcessor &processor = pr->uGet();
 #ifdef __U_DEBUG_H__
-			uDebugPrt( "%d (uLocalDebugger &)0x%p.uCreateLocalDebugger, processor is 0x%p\n", __LINE__, this, processor );
-#endif /* __U_DEBUG_H__ */
-			pdu.createNcreateKernelThread( U_THIS_TASK, U_THIS_CLUSTER, processor, cluster, processor->uPid, processor->uDebugIgnore );
+			uDebugPrt( "%d (uLocalDebugger &)0x%p.uCreateLocalDebugger, processor is 0x%p\n", __LINE__, this, &processor );
+#endif // __U_DEBUG_H__
+			pdu.createNcreateKernelThread( U_THIS_TASK, U_THIS_CLUSTER, &processor, &cluster, processor.uPid, processor.uDebugIgnore );
 			send( pdu );
 			receive();
 		} // for
 
 		// register tasks on the cluster
 		uBaseTaskDL *bt;
-		for ( uSeqGen<uBaseTaskDL> tgen( cluster->uTasksOnCluster ); tgen >> bt; ) {
-			uBaseTask *task = &bt->uGet();
+		for ( uSeqGen<uBaseTaskDL> tgen( cluster.uTasksOnCluster ); tgen >> bt; ) {
+			uBaseTask &task = bt->uGet();
 #ifdef __U_DEBUG_H__
-			uDebugPrt( "%d (uLocalDebugger &)0x%p.uCreateLocalDebugger, task %s (0x%p)\n", __LINE__, this, task->uGetName(), task );
-#endif /* __U_DEBUG_H__ */
+			uDebugPrt( "%d (uLocalDebugger &)0x%p.uCreateLocalDebugger, task %s (0x%p)\n", __LINE__, this, task.uGetName(), &task );
+#endif // __U_DEBUG_H__
 			// ignore  boot, system, local debugger, dispatcher and processor tasks
 
-			if ( task != uKernelModule::uTaskBoot && task != uKernelModule::uTaskSystem &&
-				 task != uLocalDebuggerInstance && task != dispatcher && &task->uBound == (uProcessor *)0 ) {
+			if ( &task != uKernelModule::uTaskBoot && &task != uKernelModule::uTaskSystem &&
+				 &task != uLocalDebuggerInstance && &task != dispatcher && &(task.uBound) == (uProcessor *)0 ) {
 				// retrieve some important registers
 				MinimalRegisterSet regs;
-				int *registers = (int *)task->uTaskDebugMask;
+				int *registers = (int *)task.uTaskDebugMask;
 				regs.pc = 0;
 				regs.fp = registers[0];
 				regs.sp = registers[1];
 #ifdef __U_MULTI__
-				pdu.createNattachULThread( task, U_THIS_TASK, cluster, regs, task->uGetName() );
+				pdu.createNattachULThread( &task, U_THIS_TASK, &cluster, regs, task.uGetName() );
 #else
 				// in uni-processor, pretend that every task exist on the system cluster
-				pdu.createNattachULThread( task, U_THIS_TASK, uKernelModule::uSystemCluster, regs, task->uGetName() );
+				pdu.createNattachULThread( &task, U_THIS_TASK, uKernelModule::uSystemCluster, regs, task.uGetName() );
 #endif
 				send( pdu );
 				receive();
-#if defined( __svr4__ )
-				memset( task->uTaskDebugMask, 0, 8 );
-#else
-				bzero( task->uTaskDebugMask, 8 );
-#endif 
+				memset( task.uTaskDebugMask, 0, 8 );
 			} // if
 		} // for
 	} // for
@@ -451,26 +441,29 @@ void uLocalDebugger::uCreateLocalDebugger( int port, char *machine, char *name )
 
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.uCreateLocalDebugger, done\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 } // uLocalDebugger::uCreateLocalDebugger
 
 
 uLocalDebugger::uLocalDebugger( char *port, char *machine, char *name ) :
-		uBaseTask ( *uKernelModule::uSystemCluster ),  port( atoi(port) ), machine( machine ), name( name ), pdu( *new uDebuggerProtocolUnit ) {
+		uBaseTask ( *uKernelModule::uSystemCluster ), port( atoi(port) ), machine( machine ), name( name ), pdu( *new uDebuggerProtocolUnit ) {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.uLocalDebugger( port:%s, machine:%s, name:%s, done\n", __LINE__, this, port, machine, name );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
 	debugger_blocked_tasks = 0;
 	uLocalDebuggerActive = true;
 	attaching = false;
+#ifdef __U_DEBUG_H__
+    uDebugPrt( "%d (uLocalDebugger &)0x%p.uLocalDebugger, exit( port:%s, machine:%s, name:%s, done\n", __LINE__, this, port, machine, name );
+#endif // __U_DEBUG_H__
 } // uLocalDebugger::uLocalDebugger
 
 
 uLocalDebugger::uLocalDebugger( int port ) : uBaseTask ( *uKernelModule::uSystemCluster ), port( port ), pdu( *new uDebuggerProtocolUnit ) {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.uLocalDebugger( port:%d ), done\n", __LINE__, this, port );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
 	debugger_blocked_tasks = 0;
 	uLocalDebuggerActive = true;
@@ -481,35 +474,35 @@ uLocalDebugger::uLocalDebugger( int port ) : uBaseTask ( *uKernelModule::uSystem
 uLocalDebugger::~uLocalDebugger() {
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d (uLocalDebugger &)0x%p.~uLocalDebugger, called\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
 	uLocalDebuggerActive = false;
 	delete &pdu;
 
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d (uLocalDebugger &)0x%p.~uLocalDebugger, done\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 } // uLocalDebugger::~uLocalDebugger
 
 
 void uLocalDebugger::send( uDebuggerProtocolUnit &pdu ) {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.send, type %d, total_size %d\n", __LINE__, this, pdu.getType(), pdu.total_size() );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
     uAssert( uLocalDebuggerActive );
     sockClient->write( pdu.total_buffer(), pdu.total_size() );
 
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.send, done\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 } // uLocalDebugger::send
 
 
 void uLocalDebugger::receive() {						// only called by the local debugger
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.receive, task %s (0x%p) goes to sleep\n", __LINE__, this, (U_THIS_TASK)->uGetName(), U_THIS_TASK );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
     uAssert( uLocalDebuggerActive );
     debugger_blocked_tasks += 1;
@@ -518,14 +511,14 @@ void uLocalDebugger::receive() {						// only called by the local debugger
 
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.receive, done\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 } // uLocalDebugger::receive
 
 
 bool uLocalDebugger::receive( uDebuggerProtocolUnit &pdu ) {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.receive, task %s (0x%p) goes to sleep / pdu is 0x%p\n", __LINE__, this, (U_THIS_TASK)->uGetName(), U_THIS_TASK, &pdu );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
     uAssert( uLocalDebuggerActive );
     debugger_blocked_tasks += 1;
@@ -537,7 +530,7 @@ bool uLocalDebugger::receive( uDebuggerProtocolUnit &pdu ) {
 
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.receive, done, 0x%p woke up\n", __LINE__, this, U_THIS_TASK );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
 	return true;
 } // uLocalDebugger::receive
@@ -549,22 +542,22 @@ uLocalDebugger::blockedNode::blockedNode( uBaseTask *key, uDebuggerProtocolUnit
 void uLocalDebugger::unblockTask( uBaseTask *ul_thread, uDebuggerProtocolUnit &pdu ) {
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d (uLocalDebugger &)0x%p.unblockTask, waking 0x%p\n", __LINE__, this, ul_thread );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
 	blockedNode *p;
 	for ( uSeqGen<blockedNode> gen(blockedTasks); gen >> p; ) {	// search for thread
 	  if ( p->key == ul_thread ) break;
 	} // for
 
-	if ( p != (blockedNode *)0 ) {						// found
+	if ( p != NULL ) {									// found
 		p->pdu = pdu;									// copy result
-		pdu = pdu;						// copy result
+		pdu = pdu;										// copy result
 		uSignal p->wait;								// wake thread
 	} // if
 
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d (uLocalDebugger &)0x%p.unblockTask, woke 0x%p\n", __LINE__, this, ul_thread );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 } // uLocalDebugger::unblockTask
 
 
@@ -574,7 +567,7 @@ int uLocalDebugger::breakpointHandler( int no ) {
 
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d (uLocalDebugger &)0x%p.breakpointHandler, %d called\n", __LINE__, this, no );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
 	// save some important registers
 	CREATE_MINIMAL_REGISTER_SET( regs );
@@ -592,7 +585,7 @@ int uLocalDebugger::breakpointHandler( int no ) {
 					   cond->bp_cond.var[0].vtype,
 					   cond->bp_cond.var[1].offset, cond->bp_cond.var[1].field_off, cond->bp_cond.var[1].atype,
 					   cond->bp_cond.var[1].vtype,cond->getOperator());
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
 			// The following uAssert statement is a precaution - the
 			// global debugger should not send unsupported breakpoint
@@ -608,11 +601,7 @@ int uLocalDebugger::breakpointHandler( int no ) {
 	} // if
 
 	if ( ! cond || cond->getOperator() == BreakpointCondition::NONE || cond->evaluate() ) {
-#if defined( __svr4__ )
 		memset( U_THIS_TASK->uTaskDebugMask, 0, 8 );
-#else
-		bzero( U_THIS_TASK->uTaskDebugMask, 8 );
-#endif 
 		pdu.createNhitBreakpoint( U_THIS_TASK, no, regs );
 		send( pdu );
 		if ( receive( pdu ) ) {
@@ -622,7 +611,7 @@ int uLocalDebugger::breakpointHandler( int no ) {
 	} // if
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d uLocalDebugger::breakpointHandler : leaving with adjustment : %d\n", __LINE__, adjustment );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 	return adjustment;
 } // uLocalDebugger::breakpointHandler
 
@@ -637,14 +626,14 @@ void uLocalDebugger::performAtomicOperation() {
 
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.performAtomicOperation, sending atomic operation confirmation\n", __LINE__, this );
-#endif  /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
 	pdu.createCconfirmAtomicOperation( true );
 	send( pdu );
 
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.performAtomicOperation, waiting for code change check request\n", __LINE__, this );
-#endif  /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
     debugger_blocked_tasks += 1;						// pretend to be user task during this operation
 	readPDU( *sockClient, pdu );
@@ -658,18 +647,18 @@ void uLocalDebugger::performAtomicOperation() {
 #ifdef __U_DEBUG_H__
 		uDebugPrt( "%d (uLocalDebugger &)0x%p.performAtomicOperation, checking range 0x%p - 0x%p and 0x%p - 0x%p for cluster 0x%p\n",
 				   __LINE__, this, low1, high1, low2, high2, cluster );
-#endif  /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
 #ifndef __U_MULTI__
 		uSeqGen<uClusterDL> ci;
 		uClusterDL *cr;
 		for ( ci.uOver( *uKernelModule::uGlobalClusters ); ci >> cr; ) {
 			cluster = &cr->uGet();
-#endif  /* __U_MULTI__ */
+#endif // __U_MULTI__
 
 #ifdef __U_DEBUG_H__
 			uDebugPrt( "%d (uLocalDebugger &)0x%p.performAtomicOperation, checking cluster 0x%p\n", __LINE__, this, cluster );
-#endif  /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
 			uSeqGen<uBaseTaskDL> ci;
 			uBaseTaskDL *cr;
@@ -678,7 +667,7 @@ void uLocalDebugger::performAtomicOperation() {
 #ifdef __U_DEBUG_H__
 				uDebugPrt( "%d (uLocalDebugger &)0x%p.performAtomicOperation, task %s (0x%p) at 0x%p\n",
 						   __LINE__, this, cr->uGet().uGetName(), &cr->uGet(), cr->uGet().DebugPCandSRR );
-#endif  /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
 				if ( ( (long *)cr->uGet().DebugPCandSRR >= low1 && (long *)cr->uGet().DebugPCandSRR < high1 )
 					|| ( (long *)cr->uGet().DebugPCandSRR >= low2 && (long *)cr->uGet().DebugPCandSRR < high2 ) ) {
@@ -686,21 +675,21 @@ void uLocalDebugger::performAtomicOperation() {
 
 #ifdef __U_DEBUG_H__
 					uDebugPrt( "%d (uLocalDebugger &)0x%p.performAtomicOperation, interference !!!!\n", __LINE__, this );
-#endif  /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
-	goto end;
+					goto end;
 				} // if
 			} // for
 
 #ifndef __U_MULTI__
 		} // for
-#endif  /* __U_MULTI__ */
+#endif //  __U_MULTI__
 
 	  end: ;
 
 #ifdef __U_DEBUG_H__
 		uDebugPrt( "%d (uLocalDebugger &)0x%p.performAtomicOperation, sending confirmation\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
 		pdu.re_init( uDebuggerProtocolUnit::NoType );
 		pdu.createCconfirmCodeRange( result );
@@ -710,7 +699,7 @@ void uLocalDebugger::performAtomicOperation() {
 
 #ifdef __U_DEBUG_H__
 		uDebugPrt( "%d (uLocalDebugger &)0x%p.performAtomicOperation, wait for confirmation\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
 		debugger_blocked_tasks += 1;					// pretend to be user task during this operation
 		readPDU( *sockClient, pdu );
@@ -721,14 +710,14 @@ void uLocalDebugger::performAtomicOperation() {
 
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d (uLocalDebugger &)0x%p.performAtomicOperation, done, got CfinishAtomicOperation\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 } // uLocalDebugger::performAtomicOperation
 
 
 void uLocalDebugger::attachULThread( uBaseTask *this_task, uCluster *this_cluster ) {
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d (uLocalDebugger &)0x%p.attachULThread, task %s (0x%p) / cluster 0x%p\n", __LINE__, this, this_task->uGetName(), this_task, this_cluster );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
   if ( ! uLocalDebuggerActive ) return;
 
@@ -749,26 +738,22 @@ void uLocalDebugger::attachULThread( uBaseTask *this_task, uCluster *this_cluste
 	if ( receive( pdu ) ) {
 #ifdef __U_DEBUG_H__
 		uDebugPrt( "%d (uLocalDebugger &)0x%p.attachULThread, attach confirmation received\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
-#if defined( __svr4__ )
+#endif // __U_DEBUG_H__
 		memset( this_task->uTaskDebugMask, 0, 8 );
-#else
-		bzero( this_task->uTaskDebugMask, 8 );
-#endif 
 	} // if
 
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d (uLocalDebugger &)0x%p.attachULThread, done\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 } // uLocalDebugger::attachULThread
 
 
 void uLocalDebugger::checkPoint() {
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d (uLocalDebugger &)0x%p.checkPoint, task %s (0x%p) / cluster 0x%p\n", __LINE__, this, U_THIS_TASK->uGetName(), U_THIS_TASK, U_THIS_CLUSTER );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
-  if ( U_THIS_TASK == uLocalDebuggerInstance || U_THIS_TASK == dispatcher || &U_THIS_TASK->uBound != (uProcessor *)0 ) return;
+  if ( U_THIS_TASK == uLocalDebuggerInstance || U_THIS_TASK == dispatcher || &U_THIS_TASK->uBound != NULL ) return;
 	checkPointMX();
 } // uLocalDebugger::checkPoint
 
@@ -776,7 +761,7 @@ void uLocalDebugger::checkPoint() {
 void uLocalDebugger::checkPointMX() {
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d (uLocalDebugger &)0x%p.checkPointMX, task %s (0x%p) / cluster 0x%p\n", __LINE__, this, U_THIS_TASK->uGetName(), U_THIS_TASK, U_THIS_CLUSTER );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 } // uLocalDebugger::checkPointMX
 
 
@@ -784,11 +769,11 @@ void uLocalDebugger::createULThread() {
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d (uLocalDebugger &)0x%p.createULThread, task 0x%p (%s) / cluster 0x%p (%s)\n",
 			   __LINE__, this, U_THIS_TASK, U_THIS_TASK->uGetName(), U_THIS_CLUSTER, U_THIS_CLUSTER->uGetName() );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 	MinimalRegisterSet regs;
 	CREATE_MINIMAL_REGISTER_SET( regs );				// save caller information
 
-  if ( U_THIS_TASK == uLocalDebuggerInstance || U_THIS_TASK == dispatcher || &U_THIS_TASK->uBound != (uProcessor *)0 ) {
+  if ( U_THIS_TASK == uLocalDebuggerInstance || U_THIS_TASK == dispatcher || &U_THIS_TASK->uBound != NULL ) {
 		// save the regs here for attaching later on
 		int *registers = (int *)U_THIS_TASK->uTaskDebugMask;
 		registers[0] = regs.fp;
@@ -803,8 +788,9 @@ void uLocalDebugger::createULThread() {
 void uLocalDebugger::createULThreadMX( MinimalRegisterSet &regs ) {
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d (uLocalDebugger &)0x%p.createULThreadMX, task 0x%p (%s) / cluster 0x%p (%s)\n",
+
 			   __LINE__, this, U_THIS_TASK, U_THIS_TASK->uGetName(), U_THIS_CLUSTER, U_THIS_CLUSTER->uGetName() );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
   if ( ! uLocalDebuggerActive ) return;
 
@@ -822,7 +808,7 @@ void uLocalDebugger::createULThreadMX( MinimalRegisterSet &regs ) {
 	} // if
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d (uLocalDebugger &)0x%p.createULThreadMX, done\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 } // uLocalDebugger::createULThreadMX
 
 
@@ -830,7 +816,7 @@ void uLocalDebugger::destroyULThread() {
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d (uLocalDebugger &)0x%p.destroyULThread, task 0x%p (%s) / cluster 0x%p (%s)\n",
 			   __LINE__, this, U_THIS_TASK, U_THIS_TASK->uGetName(), U_THIS_CLUSTER, U_THIS_CLUSTER->uGetName() );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
   if ( U_THIS_TASK == uLocalDebuggerInstance || U_THIS_TASK == dispatcher || U_THIS_TASK == uThisProcessor().uProcTask ) return;
 
@@ -842,7 +828,7 @@ void uLocalDebugger::destroyULThreadMX() {
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d (uLocalDebugger &)0x%p.destroyULThreadMX, task 0x%p (%s) / cluster 0x%p (%s)\n",
 			   __LINE__, this, U_THIS_TASK, U_THIS_TASK->uGetName(), U_THIS_CLUSTER, U_THIS_CLUSTER->uGetName() );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
   if ( ! uLocalDebuggerActive ) return;
 
@@ -851,14 +837,14 @@ void uLocalDebugger::destroyULThreadMX() {
 
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d (uLocalDebugger &)0x%p.destroyULThreadMX, done\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 } // uLocalDebugger::destroyULThreadMX
 
 
 void uLocalDebugger::createCluster( uCluster &cluster ) {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.createCluster, cluster 0x%p\n", __LINE__, this, &cluster );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
   if ( ! uLocalDebuggerActive ) return;
 
@@ -866,14 +852,14 @@ void uLocalDebugger::createCluster( uCluster &cluster ) {
 
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.createCluster, type %d, done\n", __LINE__, this, pdu.getType() );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 } // uLocalDebugger::createCluster
 
 
 void uLocalDebugger::destroyCluster( uCluster &cluster ) {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.destroyCluster, cluster 0x%p\n", __LINE__, this, &cluster );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
   if ( ! uLocalDebuggerActive ) return;
 
@@ -881,7 +867,7 @@ void uLocalDebugger::destroyCluster( uCluster &cluster ) {
 
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.destroyCluster, done\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 } // uLocalDebugger::destroyCluster
 
 
@@ -889,7 +875,7 @@ void uLocalDebugger::createKernelThread( uProcessor &process, uCluster &cluster
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.createKernelThread, creating task: %s (0x%p), creating cluster:0x%p, process 0x%p / cluster 0x%p / pid %d\n",
 			   __LINE__, this, (U_THIS_TASK)->uGetName(), U_THIS_TASK, U_THIS_CLUSTER, &process, &cluster, process.uPid );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
   if ( ! uLocalDebuggerActive ) return;
 
@@ -898,14 +884,14 @@ void uLocalDebugger::createKernelThread( uProcessor &process, uCluster &cluster
 
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.createKernelThread, done\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 } // uLocalDebugger::createKernelThread
 
 
 void uLocalDebugger::destroyKernelThread( uProcessor &process ) {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.destroyKernelThread, process 0x%p\n", __LINE__, this, &process );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
   if ( ! uLocalDebuggerActive ) return;
 
@@ -914,14 +900,14 @@ void uLocalDebugger::destroyKernelThread( uProcessor &process ) {
 
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.destroyKernelThread, done\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 } // uLocalDebugger::destroyKernelThread
 
 
 void uLocalDebugger::migrateKernelThread( uProcessor &process, uCluster &to_cluster ) {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.migrateKernelThread, process 0x%p / to_cluster 0x%p\n", __LINE__, this, &process, &to_cluster );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
   if ( ! uLocalDebuggerActive ) return;
   if ( U_THIS_CLUSTER->uDebugIgnore || to_cluster.uDebugIgnore || process.uDebugIgnore ) return;
@@ -931,7 +917,7 @@ void uLocalDebugger::migrateKernelThread( uProcessor &process, uCluster &to_clus
 
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.migrateKernelThread, done\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 } // uLocalDebugger::migrateKernelThread
 
 
@@ -939,7 +925,7 @@ void uLocalDebugger::migrateULThread( uCluster &to_cluster ) {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.migrateULThread, task %s (0x%p) / to_cluster 0x%p\n",
 			   __LINE__, this, (U_THIS_TASK)->uGetName(), U_THIS_TASK, &to_cluster );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
   if ( U_THIS_CLUSTER->uDebugIgnore || to_cluster.uDebugIgnore ) return;
 
@@ -951,7 +937,7 @@ void uLocalDebugger::migrateULThreadMX( uCluster &to_cluster ) {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.migrateULThreadMX, task %s (0x%p) / to_cluster 0x%p\n",
 			   __LINE__, this, (U_THIS_TASK)->uGetName(), U_THIS_TASK, &to_cluster );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
   if ( ! uLocalDebuggerActive ) return;
 
@@ -960,14 +946,14 @@ void uLocalDebugger::migrateULThreadMX( uCluster &to_cluster ) {
 
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.migrateULThreadMX, done\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 } // uLocalDebugger::migrateULThreadMX
 
 
 void uLocalDebugger::finish() {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.finish, called\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
 	pdu.createNfinishLocalDebugger( false );
 } // uLocalDebugger::finish
@@ -976,7 +962,7 @@ void uLocalDebugger::finish() {
 void uLocalDebugger::cont_handler( __U_SIGTYPE__ ) {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d uLocalDebugger::cont_handler, got signal\n", __LINE__ );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 	abort_confirmed = true;
 } // cont_handler
 
@@ -984,7 +970,7 @@ void uLocalDebugger::cont_handler( __U_SIGTYPE__ ) {
 void uLocalDebugger::abortApplication() {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebugger &)0x%p.abortApplication\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 
   if ( ! uLocalDebuggerActive ) return;
   if ( U_THIS_TASK == uLocalDebuggerInstance ) return;	// prevent recursion
@@ -998,7 +984,7 @@ void uLocalDebugger::abortApplication() {
 
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "%d (uLocalDebugger &)0x%p.abortApplication, done\n", __LINE__, this );
-#endif /* __U_DEBUG_H__ */
+#endif // __U_DEBUG_H__
 } // uLocalDebugger::abortApplication
 
 
@@ -1008,31 +994,31 @@ void uLocalDebugger::abortApplication() {
 uLocalDebuggerBoot::uLocalDebuggerBoot() {
     uCount += 1;
     if ( uCount == 1 ) {
-		char *port = getenv( "_KALLIS_DEBUGGER_PORT_" );
-		char *machine = getenv( "_KALLIS_DEBUGGER_MACHINE_" );
-		char *name = getenv( "_KALLIS_DEBUGGER_TARGET_NAME_" );
+		char *port = getenv( "_KDB_DEBUGGER_PORT_" );
+		char *machine = getenv( "_KDB_DEBUGGER_MACHINE_" );
+		char *name = getenv( "_KDB_DEBUGGER_TARGET_NAME_" );
 
 		// If the magic environment variables exists, the global debugger is
 		// running and this application can connect to it through a socket.
 
-		if ( port != (char *)0 && machine != (char *)0 && name != (char *)0 ) {
+		if ( port != NULL && machine != NULL && name != NULL ) {
 			uLocalDebugger::uLocalDebuggerInstance = new uLocalDebugger( port, machine, name );
 		} // if
     } // if
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebuggerBoot &)0x%p.uLocalDebuggerBoot\n", __LINE__, this );
-#endif __U_DEBUG_H__
+#endif // __U_DEBUG_H__
 } // uLocalDebuggerBoot::uLocalDebuggerBoot
 
 uLocalDebuggerBoot::~uLocalDebuggerBoot() {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "%d (uLocalDebuggerBoot &)0x%p.~uLocalDebuggerBoot\n", __LINE__, this );
-#endif __U_DEBUG_H__
+#endif // __U_DEBUG_H__
     uCount -= 1;
     if ( uCount == 0 ) {
-		if ( uLocalDebugger::uLocalDebuggerInstance != (uLocalDebugger *)0 ) {
+		if ( uLocalDebugger::uLocalDebuggerInstance != NULL ) {
 			delete uLocalDebugger::uLocalDebuggerInstance;
-			uLocalDebugger::uLocalDebuggerInstance = (uLocalDebugger *)0; // no more calls to local debugger
+			uLocalDebugger::uLocalDebuggerInstance = NULL; // no more calls to local debugger
 		} // if
     } // if
 } // uLocalDebuggerBoot::~uLocalDebuggerBoot
@@ -1046,5 +1032,5 @@ void uLocalDebugger::uLocalDebuggerEndCode() {}
 
 // Local Variables: //
 // tab-width: 4 //
-// compile-command: "dmake" //
+// compile-command: "gmake install" //
 // End: //
