@@ -1,21 +1,33 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Martin Karsten 1995
+// uC++ Version 5.0.1, Copyright (C) Martin Karsten 1995
 // 
 // uLocalDebugger.h -- 
 // 
 // Author           : Martin Karsten
 // Created On       : Thu Apr 20 21:32:37 1995
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sun Dec  6 09:34:22 1998
-// Update Count     : 203
+// Last Modified On : Sat Jul 17 12:46:58 2004
+// Update Count     : 210
+//
+// This  library is free  software; you  can redistribute  it and/or  modify it
+// under the terms of the GNU Lesser General Public License as published by the
+// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
+// option) any later version.
+// 
+// This library is distributed in the  hope that it will be useful, but WITHOUT
+// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
+// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
+// for more details.
+// 
+// You should  have received a  copy of the  GNU Lesser General  Public License
+// along  with this library.
 // 
 
 
 #ifndef __U_LOCALDEBUGGER_H__
 // Set preprocessor variable if debugger works for that CPU/OS.
 #if defined( __U_DEBUG__ ) && (	\
-							   ( defined( __sparc__ ) && defined( __sunos__ ) ) ||	\
 							   ( defined( __sparc__ ) && defined( __svr4__ ) ) ||	\
 							   ( defined( __i386__ )  && defined( __linux__ ) )	\
 							   )
@@ -54,8 +66,7 @@ uTask uLocalDebugger {
 	friend uTask uLocalDebuggerReader;					// access: finish, performAtomicOperation, setConditionMask, resetConditionMask
 	friend void uAbort( const char *fmt, ... );			// access: uLocalDebuggerInstance, uLocalDebuggerActive, abortApplication
 	friend uTask uProfiler;								// access: dispatcher
-	friend void readPDU( uSocketClient &sockClient, uDebuggerProtocolUnit &pdu ); // access: uGlobalDebuggerActive
-	friend void uMachContext::uInvokeTask( uBaseTask &This ); // uLocalDebuggerInstance, uLocalDebuggerActive, createULThread, destroyULThread
+	friend class uMachContext;							// uLocalDebuggerInstance, uLocalDebuggerActive, createULThread, destroyULThread
 
 	static bool uGlobalDebuggerActive;					// true => active, false => inactive (global debugger gone)
 	static bool uLocalDebuggerActive;					// true => active, false => inactive (local debugger gone)
@@ -90,6 +101,8 @@ uTask uLocalDebugger {
 
 	static void uLocalDebuggerBeginCode();
 	static void uLocalDebuggerEndCode();
+	// TEMPORARY: should be a static free routine but has to be a friend, too.
+	static void readPDU( uSocketClient &sockClient, uDebuggerProtocolUnit &pdu );
 
 	void setConditionMask( int no, void *ul_thread_id );
 	void resetConditionMask( int no, void *ul_thread_id );
@@ -140,10 +153,10 @@ class uLocalDebuggerBoot {
 }; // uLocalDebuggerBoot
 
 
-#endif __U_LOCALDEBUGGER_H__
+#endif // __U_LOCALDEBUGGER_H__
 
 
 // Local Variables: //
 // tab-width: 4 //
-// compile-command: "dmake" //
+// compile-command: "gmake install" //
 // End: //
