@@ -1,21 +1,21 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
 // 
 // Bench.cc -- Timing benchmarks for the basic features in uC++
 // 
 // Author           : Peter A. Buhr
 // Created On       : Thu Feb 15 22:03:16 1990
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sat Feb 28 18:29:51 1998
-// Update Count     : 340
+// Last Modified On : Fri Aug 27 07:57:43 2004
+// Update Count     : 349
 // 
 
 #include <uC++.h>
 #include <uIOStream.h>
 
-int uDefaultPreemption() {
-    return 1;
+unsigned int uDefaultPreemption() {
+    return 10;
 } // uDefaultPreemption
  
 #include "Time.h"
@@ -36,7 +36,7 @@ void BlockClassCreateDelete( int N ) {
 
     StartTime = Time();
     for ( int i = 0; i < N; i += 1 ) {
-	ClassDummy dummy();
+	ClassDummy dummy __attribute__(( unused ));
     } // for
     EndTime = Time();
     uCerr << uAcquire << "\t " << ( EndTime - StartTime ) / N << uRelease;
@@ -629,7 +629,7 @@ uTask ContextSwitch {
 	int StartTime, EndTime;
 	StartTime = Time();
 	for ( int i = 1; i <= N; i += 1 ) {
-	    uYield();
+	    uYieldNoPoll();
 	} // for
 	EndTime = Time();
 	uCerr << uAcquire << "\t " << ( EndTime - StartTime ) / N << uRelease;
@@ -683,7 +683,7 @@ void uMain::main() {
     }
     uCerr << "\t" << endl;
 
-    uCerr << "comonitor";
+    uCerr << "cormonitor";
     BlockCoroutineMonitorCreateDelete( NoOfTimes );
     DynamicCoroutineMonitorCreateDelete( NoOfTimes );
     CoroutineMonitorBidirectional( NoOfTimes );
@@ -721,5 +721,5 @@ void uMain::main() {
 } // uMain::main
 
 // Local Variables: //
-// compile-command: "../../bin/u++ -O3 -nodebug -msupersparc Bench.cc" //
+// compile-command: "../../bin/u++ -O2 -nodebug Bench.cc" //
 // End: //
