@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
 // 
 // DatingTask.cc -- Exchanging Values Between Tasks
 // 
 // Author           : Peter A. Buhr
 // Created On       : Fri Jul 15 16:25:41 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Jul  4 20:11:32 1996
-// Update Count     : 11
+// Last Modified On : Wed Jan 28 23:20:48 2004
+// Update Count     : 13
 // 
 
 #include <uC++.h>
@@ -83,10 +83,11 @@ uTask Boy {
 	} // Boy
 }; // Boy
 
-#define NoOfGirls 20
-#define NoOfBoys 20
 
 void uMain::main() {
+	const int NoOfGirls = 20;
+	const int NoOfBoys = 20;
+
 	DatingService TheExchange;
 	Girl *girls;
 	Boy  *boys;
