@@ -1,6 +1,6 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
 // 
 // Fib.cc --   Produce the fibonacci numbers in sequence on each call.
 //
@@ -11,9 +11,9 @@
 // 
 // Author           : Peter A. Buhr
 // Created On       : Thu Aug  2 11:55:37 1990
-// Last Modified By : Peter Buhr
-// Last Modified On : Wed May 11 17:29:25 1994
-// Update Count     : 32
+// Last Modified By : Peter A. Buhr
+// Last Modified On : Thu Jun 10 11:15:39 2004
+// Update Count     : 34
 // 
 
 #include <uC++.h>
@@ -22,7 +22,7 @@
 uCoroutine fibonacci {
     int fn;
 
-    void main( void ) {
+    void main() {
 	int fn1, fn2;
 
 	fn = 1;						// special case f0
@@ -40,7 +40,7 @@ uCoroutine fibonacci {
 	} // for
     } // fibonacci::main
   public:
-    int next( void ) {
+    int next() {
 	uResume;
 	return fn;
     }; // next
