@@ -1,6 +1,6 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
 // 
 // FibPar.cc -- Produce the fibonacci numbers in sequence on each call.
 //
@@ -14,13 +14,12 @@
 // Author           : Peter A. Buhr
 // Created On       : Thu Aug  2 11:55:37 1990
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Jul  4 20:12:12 1996
-// Update Count     : 80
+// Last Modified On : Sun Aug  8 08:51:47 2004
+// Update Count     : 84
 // 
 
 #include <uC++.h>
 #include <uIOStream.h>
-#include <unistd.h>					// prototype: getpid
 
 
 uMutex uCoroutine fibonacci {
@@ -71,15 +70,8 @@ void uMain::main() {
     srand( getpid() );
     uCout << "Fibonacci Numbers" << endl;
 
-    Worker *workers[NoOfWorkers];
-    int i;
-
-    for ( i = 0; i < NoOfWorkers; i += 1 ) {
-	workers[i] = new Worker( f1, f2 );
-    } // for
-    for ( i = 0; i < NoOfWorkers; i += 1 ) {
-	delete workers[i];
-    } // for
+    Worker *workers = new Worker[NoOfWorkers]( f1, f2 );
+    delete [] workers;
 
     uCout << uAcquire << "successful completion" << endl << uRelease;
 } // uMain::main
