@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
 // 
 // File.cc -- Print multiple copies of the same file to standard output
 // 
 // Author           : Peter A. Buhr
 // Created On       : Tue Jan  7 08:44:56 1992
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sun Nov 26 18:13:16 1995
-// Update Count     : 32
+// Last Modified On : Tue Jul 22 08:41:44 2003
+// Update Count     : 34
 // 
 
 #include <uC++.h>
@@ -23,10 +23,11 @@ uTask Copier {
 		int count;
 		char buf[1];
 
-		for ( ;; ) {									// copy in-file to out-file
+		for ( int i = 0;; i += 1 ) {					// copy in-file to out-file
 			count = in.read( buf, sizeof( buf ) );
 		  if ( count == 0 ) break;						// eof ?
 			uCout << buf[0];
+			if ( i % 20 == 0 ) uYield();
 		} // for
 	} // Copier::main
   public:
