@@ -1,6 +1,6 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Peter A. Buhr 1999
+// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1999
 // 
 // ServerINET2.cc -- Server for INET/datagram socket test. Server reads data
 // from multiple clients. The server reads the data from the client and writes
@@ -9,8 +9,8 @@
 // Author           : Peter A. Buhr
 // Created On       : Thu Apr 29 16:02:50 1999
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon May 24 11:33:12 1999
-// Update Count     : 8
+// Last Modified On : Sun Aug  8 17:10:50 2004
+// Update Count     : 23
 // 
 
 #include <uC++.h>
@@ -24,13 +24,13 @@ uTask reader {
     uSocketServer &server;
 
     void main() {
-		uDuration timeout( 60, 0 );						// timeout for read
+		uDuration timeout( 10, 0 );						// timeout for read
         char buf[BufferSize];
 		int len;
 
 		try {
 			for ( ;; ) {
-				int len = server.recvfrom( buf, sizeof(buf), 0, &timeout );
+				len = server.recvfrom( buf, sizeof(buf), 0, &timeout );
 				// uCerr << uAcquire << "Server::reader read len:" << len << endl << uRelease;
 				server.sendto( buf, len );				// write byte back to client
 			} // for
