@@ -1,21 +1,21 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
 // 
 // Migrate.cc -- Test migrating of tasks among clusters.
 // 
 // Author           : Peter Buhr
 // Created On       : Tue Jun 28 10:23:11 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Fri Oct 23 09:39:28 1998
-// Update Count     : 28
+// Last Modified On : Tue Jul 22 08:36:39 2003
+// Update Count     : 30
 // 
 
 #include <uC++.h>
 #include <uIOStream.h>
 
 
-int uDefaultPreemption() {
+unsigned int uDefaultPreemption() {
     return 1;
 } // uDefaultPreemption
 
