@@ -1,28 +1,27 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
 // 
 // Migrate.cc -- Test migrating of tasks among clusters.
 // 
 // Author           : Peter Buhr
 // Created On       : Tue Jun 28 10:23:11 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Fri Oct 23 09:39:21 1998
-// Update Count     : 77
+// Last Modified On : Sun Aug  8 08:53:42 2004
+// Update Count     : 83
 // 
 
 #include <uC++.h>
 #include <uIOStream.h>
-#include <stdio.h>
 
 
 #define NoOfClusters 2
 
-int uDefaultPreemption() {
+unsigned int uDefaultPreemption() {
     return 1;
 } // uDefaultPreemption
 
-int uDefaultSpin() {
+unsigned int uDefaultSpin() {
     return 1000;
 } // uDefaultSpin
 
@@ -47,9 +46,10 @@ uTask dummy {
     } // dummy::dummy
 }; // dummy
 
-#define NoOfTasks 3
 
 void uMain::main() {
+    const int NoOfTasks = 3;
+
     uCluster *c[NoOfClusters];
     uProcessor *p[NoOfClusters];
     dummy *t[NoOfTasks];
@@ -75,7 +75,7 @@ void uMain::main() {
 	delete c[i];
     } // for
 
-    uCout << "successful completion:" << endl;
+    uCout << "successful completion" << endl;
 } // uMain::main
 
 // Local Variables: //
