@@ -1,30 +1,30 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Peter A. Buhr 1996
+// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1996
 // 
 // MutexOwner.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Tue Feb  6 13:51:59 1996
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Aug 24 13:13:40 1998
-// Update Count     : 10
+// Last Modified On : Mon Jun 21 10:30:49 2004
+// Update Count     : 17
 // 
 
 #include <uC++.h>
 #include <uIOStream.h>
 
-uCoMonitor tom {
+uCorMonitor tom {
   public:
-    reset() {
-	uCout << uAcquire << "(" << &uThisTask() << ") tom::reset" << endl << uRelease;
-    }
     tom() {
 	reset();
     }
+    void reset() {
+	uCout << uAcquire << "(" << &uThisTask() << ") tom::reset" << endl << uRelease;
+    }
 };    
 
-uCoMonitor fred : public tom {
+uCorMonitor fred : public tom {
     void main() {
 	for ( int i = 0; i < 3; i += 1 ) {
 	    mem();
@@ -32,12 +32,12 @@ uCoMonitor fred : public tom {
 	uResume;
     }
   public:
-    reset() {
-	uCout << uAcquire << "(" << &uThisTask() << ") fred::reset" << endl << uRelease;
-    }
     fred() {
 	reset();
     }
+    void reset() {
+	uCout << uAcquire << "(" << &uThisTask() << ") fred::reset" << endl << uRelease;
+    }
     void mem() {
 	uResume;
     }
@@ -46,12 +46,12 @@ uCoMonitor fred : public tom {
 uMonitor mary {
     uCondition delay;
   public:
-    mem( int i ) {
+    void mem( int i ) {
 	if ( i >= 0 ) {
 	    mem( i - 1 );
 	    uCout << uAcquire << "(" << &uThisTask() << ") mary::mem, i:" << i << endl << uRelease;
 	} else {
-	    if ( delay.uEmpty() ) {
+	    if ( delay.empty() ) {
 		uWait delay;
 	    } else {
 		uSignal delay;
@@ -64,7 +64,7 @@ uTask jane {
     mary &m;
   public:
     jane( mary &m ) : m( m ) {}
-    mem( int i ) {
+    void mem( int i ) {
 	if ( i == 2 ) {
 	    m.mem( i );
 	} // if
