@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Philipp E. Lim and Ashif S. Harji 1996
+// uC++ Version 5.0.1, Copyright (C) Philipp E. Lim and Ashif S. Harji 1996
 // 
 // PeriodicTaskTest.cc -- 
 // 
 // Author           : Philipp E. Lim and Ashif S. Harji
 // Created On       : Tue Jul 23 14:48:37 1996
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Mon Jul  6 09:14:46 1998
-// Update Count     : 113
+// Last Modified On : Fri Aug 13 08:49:18 2004
+// Update Count     : 120
 // 
 
 // When run multiprocessor, migration to the system cluster to perform I/O
@@ -18,11 +18,12 @@
 
 #include <uC++.h>
 #include <uRealTime.h>
+#include <uDeadlineMonotonic.h>
 #include <uIOStream.h>
 #include <uIOManip.h>
-#include <uDeadlineMonotonic.h>
 
 
+const int Delay = 100000;
 uTime Start;						// global start time for all tasks
 
 
@@ -77,6 +78,7 @@ uPeriodicTask TestTask {
 	{
 	    AcrossCxtSw acrossCxtSw( delay );		// cause delay to advance across a context switch interval
 	    do {
+		for ( int i = 0; i < Delay; i += 1 );	// don't spend too much time in non-interruptible clock routine
 		currtime = uThisProcessor().uGetClock().uGetTime();
 	    } while ( delay > currtime );
 	}
@@ -85,8 +87,9 @@ uPeriodicTask TestTask {
 	    setw(3) << endtime - starttime << " seconds later" << endl << uRelease;
     } // TestTask::main
   public:
-    TestTask( int id, uDuration period, uDuration deadline, uCluster &clust ) : C( deadline ), id( id ),
-    		uPeriodicBaseTask( period, uTime(0), uThisProcessor().uGetClock().uGetTime()+90, deadline, clust ) {
+    TestTask( int id, uDuration period, uDuration deadline, uCluster &clust ) :
+	    uPeriodicBaseTask( period, uTime(0), uThisProcessor().uGetClock().uGetTime()+90, deadline, clust ),
+	    C( deadline ), id( id ) {
     } // TestTask::TestTask
 }; // TestTask
 
