@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
 // 
 // RWEx1.cc -- Readers and Writer Problem
 // 
 // Author           : Peter A. Buhr
 // Created On       : Thu Aug  2 11:51:34 1990
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Jul  4 20:13:54 1996
-// Update Count     : 82
+// Last Modified On : Mon Jun 21 10:27:02 2004
+// Update Count     : 87
 // 
 
 #include <uC++.h>
@@ -25,11 +25,11 @@ uMonitor ReaderWriter {
 	} // ReaderWriter
 
 	void StartRead() {
-		if ( WriteUsage || !ReaderAndWriter.uEmpty() ) {
+		if ( WriteUsage || ! ReaderAndWriter.empty() ) {
 			uWait ReaderAndWriter uWith READER;
 		} // if
 		ReadCount += 1;
-		if ( ! ReaderAndWriter.uEmpty() && ReaderAndWriter.uFront() == READER ) {
+		if ( ! ReaderAndWriter.empty() && ReaderAndWriter.front() == READER ) {
 			uSignal ReaderAndWriter;
 		} // if
 	} // ReaderWriter::StartRead
@@ -55,7 +55,7 @@ uMonitor ReaderWriter {
 }; // ReaderWriter
 
 
-int SharedVar = 0;										// shared variable to test readers and writers
+volatile int SharedVar = 0;								// shared variable to test readers and writers
 
 uTask Worker {
 	ReaderWriter &rw;
