@@ -1,14 +1,14 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Philipp E. Lim and Ashif S. Harji 1996
+// uC++ Version 5.0.1, Copyright (C) Philipp E. Lim and Ashif S. Harji 1996
 // 
 // RealTimePhilosophers.cc -- 
 // 
 // Author           : Philipp E. Lim and Ashif S. Harji
 // Created On       : Tue Jul 23 14:58:56 1996
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Feb 10 10:11:49 1999
-// Update Count     : 66
+// Last Modified On : Fri Aug 13 08:24:30 2004
+// Update Count     : 71
 // 
 
 // When run multiprocessor, migration to the system cluster to perform I/O
@@ -22,6 +22,7 @@
 #include <uDeadlineMonotonic.h>
 
 
+const int Delay = 100000;
 uTime Start;						// global start time for all tasks
 
 
@@ -65,6 +66,7 @@ uRealTimeMonitor RestRoom {
 	{
 	    AcrossCxtSw acrossCxtSw( delay );
 	    do {
+		for ( int i = 0; i < Delay; i += 1 );	// don't spend too much time in non-interruptible clock routine
 		currtime = uThisProcessor().uGetClock().uGetTime();
 	    } while ( delay > currtime );
 	}
@@ -96,6 +98,7 @@ uRealTimeMonitor RestRoom {
 	{
 	    AcrossCxtSw acrossCxtSw( delay );
 	    do {
+		for ( int i = 0; i < Delay; i += 1 );	// don't spend too much time in non-interruptible clock routine
 		currtime = uThisProcessor().uGetClock().uGetTime();
 	    } while ( delay > currtime );
 	}
@@ -117,9 +120,10 @@ uPeriodicTask Philosopher {
 	restroom.Wash( id, C2 );
     } // Philosopher::main
   public:
-    Philosopher( int id, uDuration period, uDuration toilet, uDuration wash, uCluster &clust ) : C1( toilet ), C2( wash ), id( id ),
-    		uPeriodicBaseTask( period, uTime(0,0), uThisProcessor().uGetClock().uGetTime()+90, period, clust ) {
-//    		uPeriodicBaseTask( period, uTime(0,0), uTime(0,0), period, clust) {
+    Philosopher( int id, uDuration period, uDuration toilet, uDuration wash, uCluster &clust ) :
+	    uPeriodicBaseTask( period, uTime(0,0), uThisProcessor().uGetClock().uGetTime()+90, period, clust ),
+//	    uPeriodicBaseTask( period, uTime(0,0), uTime(0,0), period, clust),
+	    C1( toilet ), C2( wash ), id( id ) {
     } // Philosopher::Philosopher
 }; // Philosopher
 
