@@ -1,21 +1,21 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Philipp E. Lim 1996
+// uC++ Version 5.0.1, Copyright (C) Philipp E. Lim 1996
 // 
 // Sleep.cc -- 
 // 
 // Author           : Philipp E. Lim
 // Created On       : Wed Jan 10 17:02:39 1996
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Mar 13 15:44:28 1997
-// Update Count     : 13
+// Last Modified On : Thu Jan 29 08:35:57 2004
+// Update Count     : 16
 // 
 
 #include <uC++.h>
 #include <uIOStream.h>
 
 uClock Clock;
-int x = 0, y = 1;
+volatile int x = 0, y = 1;
 
 uTask fred {
     void main() {
@@ -24,10 +24,11 @@ uTask fred {
 	  if ( x == 20 ) break;
 	    if ( x < y ) x += 1;
 	    start = Clock.uGetTime();
-	    uSleep( uDuration( 1 ) );
+	    uTimeout( uDuration( 1 ) );
 	    end = Clock.uGetTime();
 	    uCout << uAcquire << "fred slept for " << end - start << " seconds" << endl << uRelease;
 	} // for
+	uCout << uAcquire << "fred finished" << endl << uRelease;
     } // fred::main
 }; // fred
 
@@ -38,10 +39,11 @@ uTask mary {
 	  if ( y == 20 ) break;
 	    if ( y == x ) y += 1;
 	    start = Clock.uGetTime();
-	    uSleep( uDuration( 2 ) );
+	    uTimeout( uDuration( 2 ) );
 	    end = Clock.uGetTime();
 	    uCout << uAcquire << "mary slept for " << end - start << " seconds" << endl << uRelease;
 	} // for
+	uCout << uAcquire << "mary finished" << endl << uRelease;
     } // mary::main
 }; // mary
 
