@@ -1,27 +1,26 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
 // 
 // SpinLock.cc -- 
 // 
 // Author           : Peter A. Buhr
 // Created On       : Mon Feb 13 15:47:48 1995
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Fri Feb 17 20:29:31 1995
-// Update Count     : 8
+// Last Modified On : Thu Jan 29 08:37:29 2004
+// Update Count     : 12
 // 
 
 #include <uC++.h>
 #include <uIOStream.h>
 
-int uDefaultPreemption() {
+unsigned int uDefaultPreemption() {
     return 1;
 } // uDefaultPreemption
 
-uBaseTask *CurrTid;					// current task id
-
 void CriticalSection() {
-    ::CurrTid = &uThisTask();				// address of current task
+    static volatile uBaseTask *CurrTid;			// current task id
+    CurrTid = &uThisTask();				// address of current task
     
     for ( int i = 1; i <= 100; i += 1 ) {		// delay
 	// perform critical section operation
