@@ -1,45 +1,45 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
 // 
 // TimeSlice.cc -- test time slice
 // 
 // Author           : Peter A. Buhr
 // Created On       : Mon Apr 26 11:04:37 1993
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Mar 13 14:46:10 1997
-// Update Count     : 26
+// Last Modified On : Thu Jan 29 08:41:53 2004
+// Update Count     : 30
 // 
 
 #include <uC++.h>
 
-int uDefaultPreemption() {
+unsigned int uDefaultPreemption() {
     return 1;
 } // uDefaultPreemption
 
-int x = 0, y = 1;
+volatile int x = 0, y = 1;
 
-uTask fred {
+uTask T1 {
     void main() {
 	for ( ;; ) {
 	  if ( x == 100 ) break;
 	    if ( x < y ) x += 1;
 	} // for
-    } // fred::main
-}; // fred
+    } // T1::main
+}; // T1
 
-uTask mary {
+uTask T2 {
     void main() {
 	for ( ;; ) {
 	  if ( y == 100 ) break;
 	    if ( y == x ) y += 1;
 	} // for
-    } // mary::main
-}; // mary
+    } // T2::main
+}; // T2
 
 void uMain::main() {
-    fred f;
-    mary m;
+    T1 t1;
+    T2 t2;
 } // uMain::main
 
 // Local Variables: //
