@@ -1,18 +1,18 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
 // 
 // uContext.cc -- 
 // 
 // Author           : Peter Buhr
 // Created On       : Thu Jul  7 13:08:01 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Jul  4 20:14:25 1996
-// Update Count     : 9
+// Last Modified On : Sun Aug  8 08:53:23 2004
+// Update Count     : 11
 // 
 
 #include <uC++.h>
-#include <stdio.h>
+#include <cstdio>
 
 // WARNING: Do not use uCout or uCerr in uSave or uRestore as they cause a
 // recursive context switch (BAD!).
