@@ -1,19 +1,33 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Philipp E. Lim and Ashif S. Harji 1995, 1997
+// uC++ Version 5.0.1, Copyright (C) Philipp E. Lim and Ashif S. Harji 1995, 1997
 // 
 // uAlarm.cc -- 
 // 
 // Author           : Philipp E. Lim
 // Created On       : Thu Jan  4 17:34:00 1996
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Fri Jul 31 11:43:11 1998
-// Update Count     : 151
+// Last Modified On : Wed Aug 25 23:57:11 2004
+// Update Count     : 182
+//
+// This  library is free  software; you  can redistribute  it and/or  modify it
+// under the terms of the GNU Lesser General Public License as published by the
+// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
+// option) any later version.
+// 
+// This library is distributed in the  hope that it will be useful, but WITHOUT
+// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
+// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
+// for more details.
+// 
+// You should  have received a  copy of the  GNU Lesser General  Public License
+// along  with this library.
 // 
 
 
 #define __U_KERNEL__
 #include <uC++.h>
+#include <uProfiler.h>
 //#include <uDebug.h>
 
 
@@ -48,14 +62,23 @@ uEventNode::uEventNode() {
 //######################### uEventList #########################
 
 
-void uEventList::uAddEvent( uEventNode &newAlarm, uProcessor &processor ) {
+void *uEventList::operator new( size_t, void *storage ) {
+    return storage;
+} // uEventList::operator new
+
+void *uEventList::operator new( size_t size ) {
+    return ::operator new( size );
+} // uEventList::operator new
+
+
+void uEventList::uAddEvent( uEventNode &newAlarm, uProcessor &processor, bool block ) {
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uEventList &)0x%p.uAddEvent, newAlarm:0x%x, processor:0x%p\n", this, &newAlarm, &processor );
-#endif __U_DEBUG_H__
+    uDebugPrt( "(uEventList &)0x%p.uAddEvent, newAlarm:0x%p, processor:0x%p\n", this, &newAlarm, &processor );
+#endif // __U_DEBUG_H__
     uAcquireEventLock();
 
     uSeqGen<uEventNode> gen(uL);
-    uEventNode *node, *prev = (uEventNode *)0;
+    uEventNode *node, *prev = NULL;
     int i;
 
     for ( i = 0; gen >> node && node->timerT <= newAlarm.timerT; prev = node, i += 1 );
@@ -73,7 +96,12 @@ void uEventList::uAddEvent( uEventNode &newAlarm, uProcessor &processor ) {
 	    uThisCluster().uWakeProcessor( processor.uGetPid() );
 	} // if
     } // if
-    uReleaseEventLock();
+
+    if ( block ) {
+	uSCHEDULE( &uEventLock );
+    } else {
+	uReleaseEventLock();
+    } // if
 } // uEventList::uAddEvent
 
 
@@ -82,8 +110,8 @@ void uEventList::uAddEvent( uEventNode &newAlarm, uProcessor &processor ) {
 
 void uEventList::uRemoveEvent( uEventNode &oldNode, uProcessor &processor ) {
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uEventList &)0x%p.uRemoveEvent, newAlarm:0x%x, processor:0x%p\n", this, &oldNode, &processor );
-#endif __U_DEBUG_H__
+    uDebugPrt( "(uEventList &)0x%p.uRemoveEvent, newAlarm:0x%p, processor:0x%p\n", this, &oldNode, &processor );
+#endif // __U_DEBUG_H__
     uAcquireEventLock();
 
     uEventNode *headNode;
@@ -99,7 +127,7 @@ void uEventList::uRemoveEvent( uEventNode &oldNode, uProcessor &processor ) {
 	if ( this == uThisProcessor().uEvents ) {	// same processor as event list ?
 	    headNode = uL.uHead();
 	    if ( ! headNode ) {				// list empty ?
-		uActiveProcessorKernel->uSetTimer( uDuration( 0L, 0L ) ); // cancel alarm
+		uActiveProcessorKernel->uSetTimer( uDuration( 0 ) ); // cancel alarm
 	    } else {
 		uActiveProcessorKernel->uSetTimer( headNode->timerT ); // reset alarm
 	    } // if
@@ -114,13 +142,11 @@ void uEventList::uRemoveEvent( uEventNode &oldNode, uProcessor &processor ) {
 void uEventList::uPauseEvents() {
     uAcquireEventLock();
     
-    uKernelModule::uSettingTimerRF = true;
-    uActiveProcessorKernel->uSetTimer( uDuration( 0L, 0L ) );
+    uActiveProcessorKernel->uSetTimer( uDuration ( 0 ) );
 } // uEventList::uAddEvent
 
 
 void uEventList::uRestartEvents() {
-    // uKernelModule::uSettingTimerRF set to false by call to uSetTimer in uPauseEvents
     uEventNode *headNode = uL.uHead();
     if ( headNode != NULL ) {
 	uActiveProcessorKernel->uSetTimer( headNode->timerT );
@@ -133,7 +159,7 @@ void uEventList::uRestartEvents() {
 uEventNode *uEventList::uNextEvent( ) {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "(uEventList &)0x%p.uNextEvent\n", this );
-#endif __U_DEBUG_H__
+#endif // __U_DEBUG_H__
     uAcquireEventLock();
 
     uEventNode *noder;
@@ -150,7 +176,7 @@ uEventNode *uEventList::uNextEvent( ) {
 uTime uEventList::uNextAlarm( ) {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "(uEventList &)0x%p.uNextAlarm\n", this );
-#endif __U_DEBUG_H__
+#endif // __U_DEBUG_H__
     uEventNode *noder = uNextEvent();
 
     if ( noder ) {
@@ -162,13 +188,21 @@ uTime uEventList::uNextAlarm( ) {
 
 
 void uEventList::uAcquireEventLock() {
-    uEventLock.uAcquire();
+    uEventLock.acquire();
 } // uEventList::uAcquireEventLock
 
 void uEventList::uReleaseEventLock() {
-    uEventLock.uRelease();
+    uEventLock.release();
 } // uEventList::uReleaseEventLock 
 
+void uEventList::uAcquireEventLockNoRF() {
+    uEventLock.uAcquireNoRF();
+} // uEventList::uAcquireEventLockNoRF
+
+void uEventList::uReleaseEventLockNoRF() {
+    uEventLock.uReleaseNoRF();
+} // uEventList::uReleaseEventLockNoRF
+
 
 bool uEventList::uUserEventPresent() {
     uAcquireEventLock();
@@ -182,7 +216,7 @@ bool uEventList::uUserEventPresent() {
 	 );
     uReleaseEventLock();
 
-    return noder != (uEventNode *)0;
+    return noder != NULL;
 } // uEventList::uUserEventPresent
 
 
@@ -190,16 +224,21 @@ bool uEventList::uUserEventPresent() {
 
 
 uEventListPop::uEventListPop( uEventList &e, bool inKernel ) : uEL( &e ), uInKernel( inKernel ) {
+    THREAD_SETMEM( uInKernelRF, 1 );			// detect if subsequent interrupts occur
     curTime = uActiveProcessorKernel->uKernelClock.uGetTime();
     uCxtSwHandler = NULL;
 } // uEventListPop::uEventListPop
 
 uEventListPop::~uEventListPop() {
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uEventListPop &)0x%p.~uEventListPop\n", this, node );
-#endif __U_DEBUG_H__
-    uEL->uAcquireEventLock();
-    uKernelModule::uInKernelRF = 0;
+    uDebugPrt( "(uEventListPop &)0x%p.~uEventListPop\n", this );
+#endif // __U_DEBUG_H__
+    uEL->uAcquireEventLockNoRF();
+    // only reset the roll forward flag if no other interrupts occurred during
+    // roll forward
+    if ( THREAD_GETMEM( uInKernelRF ) == 1 ) {
+	THREAD_SETMEM( uInKernelRF, 0 );
+    } // if
 
     if ( ! uEL->uL.uEmpty() ) {
 	uActiveProcessorKernel->uSetTimer( uEL->uL.uHead()->timerT );
@@ -217,7 +256,7 @@ uEventListPop::~uEventListPop() {
 	    // the task on the front of the ready queue, the current task is
 	    // preempted even if it has only just started execution.
 
-	    uThisTask().uYieldNoPoll();
+	    uThisTask().uYieldInvoluntary();
 	} // if
     } else {
 	// roll-forward is only called from the kernel, after waking up from
@@ -229,7 +268,7 @@ uEventListPop::~uEventListPop() {
 	// A preemption event may be ignored because a reschedule is just about
 	// to occur, anyway, when the kernel reschedules the next task.
 
-	uAssert( uKernelModule::uDisableInt && uKernelModule::uDisableIntCnt > 0 );
+	uAssert( THREAD_GETMEM( uDisableInt ) && THREAD_GETMEM( uDisableIntCnt ) > 0 );
     } // if
 } // uEventListPop::~uEventListPop
 
@@ -242,19 +281,19 @@ void uEventListPop::uOver( uEventList &e, bool inKernel ) {
 
 bool uEventListPop::operator>>( uEventNode *&node ) {
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uEventListPop &)0x%p.>>, node:0x%x\n", this, node );
-#endif __U_DEBUG_H__
-    uEL->uAcquireEventLock();
+    uDebugPrt( "(uEventListPop &)0x%p.>>, node:0x%p\n", this, node );
+#endif // __U_DEBUG_H__
+    uEL->uAcquireEventLockNoRF();
 
     node = uEL->uL.uHead();				// get event at the start of the list with the shortest time delay
 
   if ( ! node ) {					// no events ?
-	uEL->uReleaseEventLock();
+	uEL->uReleaseEventLockNoRF();
 	return false;
     } // if
 
   if ( node->timerT > curTime ) {			// event time delay greater than the start time for the iteration
-	uEL->uReleaseEventLock();
+	uEL->uReleaseEventLockNoRF();
 	return false;
     } // if
 
@@ -272,7 +311,7 @@ bool uEventListPop::operator>>( uEventNode *&node ) {
 	// May have to order identical timed elements by priority (to keep up
 	// the real-time spirit)
 
-	for ( prev = (uEventNode *)0; i >> noder && noder->timerT <= node->timerT; prev = noder );
+	for ( prev = NULL; i >> noder && noder->timerT <= node->timerT; prev = noder );
 	if ( prev && (uSignalHandler *)(uThisProcessor().uContextSwitchHandler) == prev->SigHandler && prev->timerT == node->timerT) {
 	    noder = prev;
 	} // if
@@ -282,13 +321,13 @@ bool uEventListPop::operator>>( uEventNode *&node ) {
 
     if ( node->SigHandler == (uSignalHandler *)(uThisProcessor().uContextSwitchHandler) ) {
 	uCxtSwHandler = node->SigHandler;		// remember the context switch event
-	uEL->uReleaseEventLock();
+	uEL->uReleaseEventLockNoRF();
     } else {                                            // not a ContextSwitch event
 	if ( node->uExecuteLocked ) {			// should handler be called with lock
 	    node->SigHandler->uHandler();		// invoke the handler code for the event
-	    uEL->uReleaseEventLock();
+	    uEL->uReleaseEventLockNoRF();
 	} else {
-	    uEL->uReleaseEventLock();
+	    uEL->uReleaseEventLockNoRF();
 	    node->SigHandler->uHandler();		// invoke the handler code for the event
 	} // if
     } // if
@@ -298,5 +337,5 @@ bool uEventListPop::operator>>( uEventNode *&node ) {
 
 
 // Local Variables: //
-// compile-command: "dmake" //
+// compile-command: "gmake install" //
 // End: //
