@@ -1,43 +1,43 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
 // 
 // uCluster.cc -- 
 // 
 // Author           : Peter Buhr
 // Created On       : Mon Mar 14 17:34:24 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Feb 10 10:30:34 1999
-// Update Count     : 306
+// Last Modified On : Tue Sep  7 11:57:21 2004
+// Update Count     : 372
+//
+// This  library is free  software; you  can redistribute  it and/or  modify it
+// under the terms of the GNU Lesser General Public License as published by the
+// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
+// option) any later version.
+// 
+// This library is distributed in the  hope that it will be useful, but WITHOUT
+// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
+// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
+// for more details.
+// 
+// You should  have received a  copy of the  GNU Lesser General  Public License
+// along  with this library.
 // 
 
 
 #define __U_KERNEL__
-#ifndef __U_DEBUG__
-#define NDEBUG						// turn off assert
-#endif
+
+
 #include <uC++.h>
 #include <uAssert.h>
 //#include <uDebug.h>
 
-#include <signal.h>					// needed for SIGALRM and kill
-
-
-#if ! defined( __svr4__ ) && defined( __sun__ )
-extern "C" int sigsetmask(int);				// missing from signal.h
-extern "C" int sigblock(int);				// missing from signal.h
-extern "C" int sigpause(int);				// missing from signal.h
+#if defined( __solaris__ )
+#include <sys/lwp.h>					// needed for _lwp_kill
 #endif
 
-#if defined( __ultrix__ ) && defined( __dec__ )
-extern "C" int sigsetmask(int);				// missing from signal.h
-extern "C" int sigblock(int);				// missing from signal.h
-extern "C" int sigpause(int);				// missing from signal.h
-#endif
-
-
 extern uCluster &uThisCluster() {
-    return *uKernelModule::uActiveCluster;
+    return *THREAD_GETMEM( uActiveCluster );
 } // uThisCluster
 
 
@@ -51,76 +51,81 @@ uCluster &uClusterDL::uGet() const { return uWho; }
 //######################### uCluster #########################
 
 
+void *uCluster::operator new( size_t, void *storage ) {
+    return storage;
+} // uCluster::operator new
+
+void *uCluster::operator new( size_t size ) {
+    return ::operator new( size );
+} // uCluster::operator new
+
+
 void uCluster::uWakeProcessor( int uPid ) {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "(uCluster &)0x%p.uWakeProcessor: waking processor %d\n", this, uPid );
-#endif __U_DEBUG_H__
+#endif // __U_DEBUG_H__
+
+#if defined( __solaris__ )
+    _lwp_kill( uPid, SIGALRM );
+#else
     kill( uPid, SIGALRM );				// wake it up, as it is probably sleeping
+#endif
 } // uCluster::uWakeProcessor
 
 
 void uCluster::uProcessorPause() {
-    uAssert( uKernelModule::uDisableInt && uKernelModule::uDisableIntCnt > 0 );
+    uAssert( THREAD_GETMEM( uDisableInt ) && THREAD_GETMEM( uDisableIntCnt ) > 0 );
 
     // Check the ready queue to make sure that no task managed to slip onto the
     // queue since the processor last checked.
 
-    uReadyIdleLock.uAcquire();
+    uReadyIdleTaskLock.acquire();
     if ( uReadyTasksEmpty() && uThisProcessor().uExternal.uEmpty() ) {
 	// stop generating SIGALRM signals on this processor until woken up
 
-	uThisProcessor().uSetContextSwitchEvent( uDuration( 0, 0 ) ); // turn off context-switching
-
-	// real-time
-
-	uTime nextAlarm;
-	nextAlarm = uThisProcessor().uEvents->uNextAlarm(); // find next event time
+	uThisProcessor().uSetContextSwitchEvent( 0 );	// turn off context-switching
 
 	// Block any SIGALRM signals from arriving.
-#ifdef __svr4__
-	sighold( SIGALRM );
-#else
-	unsigned int mask = sigblock( sigmask( SIGALRM ) );
-#endif __svr4__
-	if ( uKernelModule::uInKernelRF ) {		// in kernel roll-forward flag on ?
-	        uReadyIdleLock.uRelease();
-#ifdef __svr4__
-		sigrelse( SIGALRM );
-#else
-	        sigsetmask( mask );
-#endif __svr4__
-		uKernelModule::uRollForward( true );	// make sure to do chores
+	sigset_t new_mask, mask;
+	sigemptyset( &new_mask );
+	sigaddset( &new_mask, SIGALRM );
+	if ( sigprocmask( SIG_BLOCK, &new_mask, &mask ) == -1 ) {
+	    uAbort( "internal error, sigprocmask" );
+	} // if
+
+	if ( THREAD_GETMEM( uInKernelRF ) ) { // in kernel roll-forward flag on ?
+	        uReadyIdleTaskLock.release();
+		if ( sigprocmask( SIG_SETMASK, &mask, NULL ) == -1 ) {
+		    uAbort( "internal error, sigprocmask" );
+		} // if
+		THREAD_GETMEM( uSelf )->uRollForward( true ); // make sure to do chores
 	} else {
 	    uIdleProcessors.uAddTail( &(uThisProcessor().uIdleRef) );
-	    uReadyIdleLock.uRelease();
+	    uReadyIdleTaskLock.release();
 
 	    // Install the old signal mask and wait for a signal to arrive.
 
 #ifdef __U_DEBUG_H__
 	    uDebugPrt( "(uCluster &)0x%p.uProcessorPause, before sigpause\n", this );
-#endif __U_DEBUG_H__
-#ifdef __svr4__
-	    sigpause( SIGALRM );
-	    sigrelse( SIGALRM );
-#else
-	    sigpause( mask );
-	    sigsetmask( mask );
-#endif __svr4__
-
+#endif // __U_DEBUG_H__
+	    sigsuspend( &mask );
+	    if ( sigprocmask( SIG_SETMASK, &mask, NULL ) == -1 ) {
+		uAbort( "internal error, sigprocmask" );
+	    } // if
 #ifdef __U_DEBUG_H__
 	    uDebugPrt( "(uCluster &)0x%p.uProcessorPause, after sigpause\n", this );
-#endif __U_DEBUG_H__
+#endif // __U_DEBUG_H__
 
 	    // A UNIX process may be woken by any signal, e.g. SIGCHLD, so it is
 	    // necessary to check and remove the processor from the idle queue.
 	    // Normally a processor is removed in uMakeTaskReady.
 
 	    if ( uThisProcessor().uIdle() ) {
-		uReadyIdleLock.uAcquire();
+		uReadyIdleTaskLock.acquire();
 		if ( uThisProcessor().uIdle() ) {
 		    uIdleProcessors.uRemove( &(uThisProcessor().uIdleRef) );
 		} // if
-		uReadyIdleLock.uRelease();
+		uReadyIdleTaskLock.release();
 	    } // if
 
 	    // Just woken up after an alarm but in kernel/library code, so no
@@ -129,36 +134,48 @@ void uCluster::uProcessorPause() {
 	    // Therefore, do a roll-forward to ensure that any necessary events
 	    // are popped from the event list.
 
-	    uKernelModule::uRollForward( true );
+	    THREAD_GETMEM( uSelf )->uRollForward( true );
 	} // if
 
 	// Reset the context-switch
 
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "(uCluster &)0x%p.uProcessorPause, reset timeslice:%d\n", this, uThisProcessor().uGetPreemption() );
-#endif __U_DEBUG_H__
+#endif // __U_DEBUG_H__
 	uThisProcessor().uSetContextSwitchEvent( uThisProcessor().uGetPreemption() );
     } else {
-	uReadyIdleLock.uRelease();
+	uReadyIdleTaskLock.release();
     } // if
 
-    uAssert( uKernelModule::uDisableInt && uKernelModule::uDisableIntCnt > 0 );
+    uAssert( THREAD_GETMEM( uDisableInt ) && THREAD_GETMEM( uDisableIntCnt ) > 0 );
 } // uCluster::uProcessorPause
 
 
 void uCluster::uMakeProcessorIdle( uProcessor &p ) {
-    uReadyIdleLock.uAcquire();
+    uReadyIdleTaskLock.acquire();
     uIdleProcessors.uAddTail( &(p.uIdleRef) );
-    uReadyIdleLock.uRelease();
+    uReadyIdleTaskLock.release();
 } // uCluster::uMakeProcessorIdle
 
 
 void uCluster::uMakeProcessorActive( uProcessor &p ) {
-    uReadyIdleLock.uAcquire();
+    uReadyIdleTaskLock.acquire();
     if ( p.uIdle() ) {					// processor on idle queue ?
 	uIdleProcessors.uRemove( &(p.uIdleRef) );
     } // if
-    uReadyIdleLock.uRelease();
+    uReadyIdleTaskLock.release();
+} // uCluster::uMakeProcessorActive
+
+
+void uCluster::uMakeProcessorActive() {
+    uReadyIdleTaskLock.acquire();
+    if ( ! uReadyTasks->uEmpty() && ! uIdleProcessors.uEmpty() ) {
+	int uPid = uIdleProcessors.uDropHead()->uGet().uPid;
+	uReadyIdleTaskLock.release();			// don't hold lock while sending SIGALRM
+	uWakeProcessor( uPid );
+    } else {
+	uReadyIdleTaskLock.release();
+    } // if
 } // uCluster::uMakeProcessorActive
 
 
@@ -168,31 +185,31 @@ bool uCluster::uReadyTasksEmpty() {
 
 
 void uCluster::uMakeTaskReady( uBaseTask &uReadyTask ) {
-    uReadyIdleLock.uAcquire();
-    if ( &uReadyTask.uBound ) {				// task bound to a specific processor ?
+    uReadyIdleTaskLock.acquire();
+    if ( &uReadyTask.uBound != NULL ) {			// task bound to a specific processor ?
 #ifdef __U_DEBUG_H__
-	uDebugPrt( "(uCluster &)0x%p.uMakeTaskReady(1): task 0x%p (%.256s) makes task 0x%p (%.256s) ready\n",
-		  this, &uThisTask(), uThisTask().uGetName(), &uReadyTask, uReadyTask.uGetName() );
-#endif __U_DEBUG_H__
+	uDebugPrt( "(uCluster &)0x%p.uMakeTaskReady(1): task %.256s (0x%p) makes task %.256s (0x%p) ready\n",
+		  this, uThisTask().uGetName(), &uThisTask(), uReadyTask.uGetName(), &uReadyTask );
+#endif // __U_DEBUG_H__
 	uProcessor *p = &uReadyTask.uBound;		// optimization
 	p->uExternal.uAddTail( &(uReadyTask.uReadyRef) ); // add task to end of special ready queue
 #ifdef __U_MULTI__
 	if ( p->uIdle() ) {				// processor on idle queue ?
 	    uIdleProcessors.uRemove( &(p->uIdleRef) );
 	    int uPid = p->uPid;
-	    uReadyIdleLock.uRelease();			// don't hold lock while sending SIGALRM
+	    uReadyIdleTaskLock.release();		// don't hold lock while sending SIGALRM
 	    uWakeProcessor( uPid );
 	} else {
-	    uReadyIdleLock.uRelease();
+	    uReadyIdleTaskLock.release();
 	} // if
 #else
-	uReadyIdleLock.uRelease();
-#endif __U_MULTI__
+	uReadyIdleTaskLock.release();
+#endif // __U_MULTI__
     } else {
 #ifdef __U_DEBUG_H__
-	uDebugPrt( "(uCluster &)0x%p.uMakeTaskReady(2): task 0x%p (%.256s) makes task 0x%p (%.256s) ready\n",
-		  this, &uThisTask(), uThisTask().uGetName(), &uReadyTask, uReadyTask.uGetName() );
-#endif __U_DEBUG_H__
+	uDebugPrt( "(uCluster &)0x%p.uMakeTaskReady(2): task %.256s (0x%p) makes task %.256s (0x%p) ready\n",
+		   this, uThisTask().uGetName(), &uThisTask(), uReadyTask.uGetName(), &uReadyTask );
+#endif // __U_DEBUG_H__
 #ifdef __U_MULTI__
 	// Wake up an idle processor if the ready task is migrating to another
 	// cluster with idle processors or if the ready task is on the same
@@ -203,16 +220,16 @@ void uCluster::uMakeTaskReady( uBaseTask &uReadyTask ) {
 	if ( ! uIdleProcessors.uEmpty() && ( &uThisCluster() != this || ! uReadyTasks->uEmpty() ) ) {
 	    uReadyTasks->uAdd( &(uReadyTask.uReadyRef) ); // add task to end of cluster ready queue
 	    int uPid = uIdleProcessors.uDropHead()->uGet().uPid;
-	    uReadyIdleLock.uRelease();			// don't hold lock while sending SIGALRM
+	    uReadyIdleTaskLock.release();		// don't hold lock while sending SIGALRM
 	    uWakeProcessor( uPid );
 	} else {
 	    uReadyTasks->uAdd( &(uReadyTask.uReadyRef) ); // add task to end of cluster ready queue
-	    uReadyIdleLock.uRelease();
+	    uReadyIdleTaskLock.release();
 	} // if
 #else
 	uReadyTasks->uAdd( &(uReadyTask.uReadyRef) );	// add task to end of cluster ready queue
-	uReadyIdleLock.uRelease();
-#endif __U_MULTI__
+	uReadyIdleTaskLock.release();
+#endif // __U_MULTI__
     } // if
 } // uCluster::uMakeTaskReady
 
@@ -223,91 +240,105 @@ uBaseTask &uCluster::uReadyTaskTryRemove() {
 
     uBaseTask *t;
 
-    uReadyIdleLock.uAcquire();
+    uReadyIdleTaskLock.acquire();
     if ( ! uReadyTasksEmpty() ) {
 	t = &(uReadyTasks->uDrop()->uGet());
     } else {
-	t = (uBaseTask *)0;
+	t = NULL;
     } // if
-    uReadyIdleLock.uRelease();
+    uReadyIdleTaskLock.release();
     return *t;
 } // uCluster::uReadyTaskTryRemove
 
 
 void uCluster::uTaskAdd( uBaseTask &t ) {
-    uReadyIdleLock.uAcquire();
+    uReadyIdleTaskLock.acquire();
     uTasksOnCluster.uAddTail( &(t.uClusterRef) );
-    uReadyTasks->uAddInitialize( uTasksOnCluster );
-    uReadyIdleLock.uRelease();
+    if ( &t.uBound == NULL ) uReadyTasks->uAddInitialize( uTasksOnCluster ); // processor task is not part of normal initialization
+    uReadyIdleTaskLock.release();
 } // uCluster::uTaskAdd
 
 
 void uCluster::uTaskRemove( uBaseTask &t ) {
-    uReadyIdleLock.uAcquire();
+    uReadyIdleTaskLock.acquire();
     uTasksOnCluster.uRemove( &(t.uClusterRef) );
-    uReadyTasks->uRemoveInitialize( uTasksOnCluster );
-    uReadyIdleLock.uRelease();
+    if ( &t.uBound == NULL ) uReadyTasks->uRemoveInitialize( uTasksOnCluster ); // processor task is not part of normal initialization
+    uReadyIdleTaskLock.release();
 } // uCluster::uTaskRemove
 
 
 void uCluster::uTaskReschedule( uBaseTask &t ) {
-    uReadyIdleLock.uAcquire();
+    uReadyIdleTaskLock.acquire();
     uReadyTasks->uRescheduleTask( &(t.uClusterRef), uTasksOnCluster );
-    uReadyIdleLock.uRelease();
+    uReadyIdleTaskLock.release();
 } // uCluster::uTaskReschedule
 
 
-void uCluster::uTaskResetPriority( uBaseTask &owner, uBaseTask &calling ) {
-    uReadyIdleLock.uAcquire();
+void uCluster::uTaskResetPriority( uBaseTask &owner, uBaseTask &calling ) { // TEMPORARY
+#ifdef __U_DEBUG_H__
+    uDebugPrt( "(uCluster &)0x%p.uTaskResetPriority, owner:0x%p, calling:0x%p, owner's cluster:0x%p\n", this, &owner, &calling, owner.uCurrCluster );
+#endif // __U_DEBUG_H__
+    uReadyIdleTaskLock.acquire();
     if ( &uThisCluster() == owner.uCurrCluster ) {
 	if ( uReadyTasks->uCheckPriority( owner.uReadyRef, calling.uReadyRef ) ) {
 	    uReadyTasks->uResetPriority( owner.uReadyRef, calling.uReadyRef );
 	} // if
     } // if
-    uReadyIdleLock.uRelease();
+    uReadyIdleTaskLock.release();
 } // uCluster::uTaskResetPriority
 
 
+void uCluster::uTaskSetPriority( uBaseTask &owner, uBaseTask &calling ) {
+#ifdef __U_DEBUG_H__
+    uDebugPrt( "(uCluster &)0x%p.uTaskSetPriority, owner:0x%p, calling:0x%p, owner's cluster:0x%p\n", this, &owner, &calling, owner.uCurrCluster );
+#endif // __U_DEBUG_H__
+    uReadyIdleTaskLock.acquire();
+    uReadyTasks->uResetPriority( owner.uReadyRef, calling.uReadyRef );
+    uReadyIdleTaskLock.release();
+} // uCluster::uTaskSetPriority
+
+
 void uCluster::uProcessorAdd( uProcessor &p ) {
-    uProcessorsOnClusterLock.uAcquire();
+    uProcessorsOnClusterLock.acquire();
     uProcessorsOnCluster.uAddTail( &(p.uProcessorRef) );
-    uProcessorsOnClusterLock.uRelease();
+    uProcessorsOnClusterLock.release();
 } // uCluster::uProcessorAdd
 
 
 void uCluster::uProcessorRemove( uProcessor &p ) {
-    uProcessorsOnClusterLock.uAcquire();
+    uProcessorsOnClusterLock.acquire();
     uProcessorsOnCluster.uRemove( &(p.uProcessorRef) );
-    uProcessorsOnClusterLock.uRelease();
+    uProcessorsOnClusterLock.release();
 } // uCluster::uProcessorRemove
 
+
 void uCluster::uCreateCluster( unsigned int stacksize, const char *name ) {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "(uCluster &)0x%p.uCreateCluster\n", this );
-#endif __U_DEBUG_H__
+#endif // __U_DEBUG_H__
 
 #ifdef __U_DEBUG__
 #ifdef __U_MULTI__
     uDebugIgnore = false;
 #else
     uDebugIgnore = true;
-#endif __U_MULTI__
-#endif __U_DEBUG__
+#endif // __U_MULTI__
+#endif // __U_DEBUG__
 
     uSetName( name );
     uSetStackSize( stacksize );
 
 #if __U_LOCALDEBUGGER_H__
     if ( uLocalDebugger::uLocalDebuggerActive ) uLocalDebugger::uLocalDebuggerInstance->checkPoint();
-#endif __U_LOCALDEBUGGER_H__
+#endif // __U_LOCALDEBUGGER_H__
 
-    uKernelModule::uGlobalClusterLock->uAcquire();
+    uKernelModule::uGlobalClusterLock->acquire();
     uKernelModule::uGlobalClusters->uAddTail( &uGlobalRef );
-    uKernelModule::uGlobalClusterLock->uRelease();
+    uKernelModule::uGlobalClusterLock->release();
 
 #if __U_LOCALDEBUGGER_H__
     if ( uLocalDebugger::uLocalDebuggerActive ) uLocalDebugger::uLocalDebuggerInstance->createCluster( *this );
-#endif __U_LOCALDEBUGGER_H__
+#endif // __U_LOCALDEBUGGER_H__
 
     if ( uReadyTasks == NULL ) {
 	uReadyTasks = new uDefaultScheduler;
@@ -315,6 +346,10 @@ void uCluster::uCreateCluster( unsigned int stacksize, const char *name ) {
     } else {
 	uDefaultReadyTasks = false;
     } // if
+
+#ifdef __U_MULTI__
+    NBIO = new uNBIO;
+#endif // __U_MULTI__
 } // uCluster::uCreateCluster
 
 
@@ -338,30 +373,56 @@ uCluster::uCluster( uBaseSchedule<uBaseTaskDL> &ReadyQueue, const char *name ) :
 } // uCluster::uCluster
 
 
+const int uCluster::uReadSelect = 1;
+const int uCluster::uWriteSelect = 2;
+const int uCluster::uExceptSelect = 4;
+
+
+int uCluster::uSelect( int fd, int rwe, timeval *timeout ) {
+    return NBIO->uSelect( fd, rwe, timeout );
+} // uCluster::uSelect
+
+
+int uCluster::uSelect( fd_set *rfd, fd_set *wfd, fd_set *efd, timeval *timeout ) {
+    return NBIO->uSelect( FD_SETSIZE, rfd, wfd, efd, timeout );
+} // uCluster::uSelect
+
+
+int uCluster::uSelect( int nfds, fd_set *rfd, fd_set *wfd, fd_set *efd, timeval *timeout ) {
+    return NBIO->uSelect( nfds, rfd, wfd, efd, timeout );
+} // uCluster::uSelect
+
+
 uCluster::~uCluster() {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "(uCluster &)0x%p.~uCluster\n", this );
-#endif __U_DEBUG_H__
+#endif // __U_DEBUG_H__
+
+#ifdef __U_MULTI__
+    delete NBIO;
+#endif // __U_MULTI__
 
 #ifdef __U_DEBUG__
-    uBaseTaskDL *tr;
-    uReadyIdleLock.uAcquire();
-    for ( uSeqGen<uBaseTaskDL> gen1(uTasksOnCluster); gen1 >> tr; ) {
-	uAbort( ": attempt to delete cluster 0x%p (%.256s) with task 0x%p (%.256s) still on it.\n"
-	       "Possible cause is that the task has not been deleted.",
-	       this, this->uGetName(), &(tr->uGet()), tr->uGet().uGetName() );
-    } // for
-    uReadyIdleLock.uRelease();
-
+    // Must check for processors before tasks because each processor has a
+    // processor task, and hence, there is always a task on the cluster.
     uProcessorDL *pr;
-    uProcessorsOnClusterLock.uAcquire();
+    uProcessorsOnClusterLock.acquire();
     for ( uSeqGen<uProcessorDL> gen2(uProcessorsOnCluster); gen2 >> pr; ) {
-	uAbort( ": attempt to delete cluster 0x%p (%.256s) with processor 0x%p still on it.\n"
-	       "Possible cause is that the processor has not been deleted.",
-	       this, this->uGetName(), &(pr->uGet()) );
+	uAbort( ": attempt to delete cluster %.256s (0x%p) with processor 0x%p still on it.\n"
+		"Possible cause is the processor has not been deleted.",
+		uGetName(), this, &(pr->uGet()) );
     } // for
-    uProcessorsOnClusterLock.uRelease();
-#endif __U_DEBUG__
+    uProcessorsOnClusterLock.release();
+
+    uBaseTaskDL *tr;
+    uReadyIdleTaskLock.acquire();
+    for ( uSeqGen<uBaseTaskDL> gen1(uTasksOnCluster); gen1 >> tr; ) {
+	uAbort( ": attempt to delete cluster %.256s (0x%p) with task %.256s (0x%p) still on it.\n"
+		"Possible cause is the task has not been deleted.",
+		uGetName(), this, tr->uGet().uGetName(), &(tr->uGet()) );
+    } // for
+    uReadyIdleTaskLock.release();
+#endif // __U_DEBUG__
 
     if ( uDefaultReadyTasks ) {				// delete if cluster allocated it
 	delete uReadyTasks;
@@ -369,11 +430,11 @@ uCluster::~uCluster() {
 
 #if __U_LOCALDEBUGGER_H__
     if ( uLocalDebugger::uLocalDebuggerActive ) uLocalDebugger::uLocalDebuggerInstance->destroyCluster( *this );
-#endif __U_LOCALDEBUGGER_H__
+#endif // __U_LOCALDEBUGGER_H__
 
-    uKernelModule::uGlobalClusterLock->uAcquire();
+    uKernelModule::uGlobalClusterLock->acquire();
     uKernelModule::uGlobalClusters->uRemove( &uGlobalRef );
-    uKernelModule::uGlobalClusterLock->uRelease();
+    uKernelModule::uGlobalClusterLock->release();
 } // uCluster::~uCluster
 
 const char *uCluster::uSetName( const char *name ) {
@@ -383,10 +444,11 @@ const char *uCluster::uSetName( const char *name ) {
 } // uCluster::uSetName
 
 const char *uCluster::uGetName() const {
+    return
 #ifdef __U_DEBUG__
-    if ( uName == NULL ) return "*unknown*";		// storage might be scrubbed
-#endif __U_DEBUG__
-    return uName;
+	( uName == NULL || uName == (const char *)-1 ) ? "*unknown*" : // storage might be scrubbed
+#endif // __U_DEBUG__
+	uName;
 } // uCluster::uGetName
 
 unsigned int uCluster::uSetStackSize( unsigned int stacksize ) {
@@ -399,73 +461,11 @@ unsigned int uCluster::uGetStackSize() const {
     return uStackSize;
 } // uCluster::uGetStackSize
 
-
-//######################### uIOCluster #########################
-
-
-void uIOCluster::uProcessorAdd( uProcessor &p ) {
-    uProcessorsOnClusterLock.uAcquire();
-    if ( uProcessorsOnCluster.uEmpty() ) {
-	uProcessorsOnCluster.uAddTail( &(p.uProcessorRef) );
-	uProcessorsOnClusterLock.uRelease();
-    } else {
-	uProcessorsOnClusterLock.uRelease();
-	uAbort( ": attempt to add or move processor 0x%p to or from I/O cluster 0x%p (%.256s).\n"
-	       "An I/O cluster (uIOCluster) can have only one processor.",
-	       &p, this, this->uGetName() );
-    } // if
-} // uIOCluster::uProcessorAdd
-
-
-void uIOCluster::uCreateIOCluster() {
-#ifdef __U_MULTI__
-    NBIO = new uNBIO;
-#endif __U_MULTI__
-} // uIOCluster::uCreateIOCluster
-
-
-uIOCluster::uIOCluster( uBaseSchedule<uBaseTaskDL> &ReadyQueue ) : uCluster( ReadyQueue, uDefaultStackSize(), "uSystemCluster" ), processor( *this, 1.0 ) {
-    uCreateIOCluster();
-} // uIOCluster::uIOCluster
-
-
-uIOCluster::uIOCluster( unsigned int stacksize, const char *name ) : uCluster( stacksize, name ), processor( *this ) {
-    uCreateIOCluster();
-} // uIOCluster::uIOCluster
-
-
-uIOCluster::uIOCluster( const char *name ) : uCluster( name ), processor( *this ) {
-    uCreateIOCluster();
-} // uIOCluster::uIOCluster
-
-
-uIOCluster::~uIOCluster() {
-#ifdef __U_MULTI__
-    delete NBIO;
-#endif __U_MULTI__
-} // uIOCluster::uIOCluster
-
-
-const int uIOCluster::uReadSelect = 1;
-const int uIOCluster::uWriteSelect = 2;
-const int uIOCluster::uExceptSelect = 4;
-
-
-int uIOCluster::uSelect( int fd, int rwe, timeval *timeout ) {
-    return NBIO->uSelect( fd, rwe, timeout );
-} // uIOCluster::uSelect
-
-
-int uIOCluster::uSelect( fd_set *rfd, fd_set *wfd, fd_set *efd, timeval *timeout ) {
-    return NBIO->uSelect( FD_SETSIZE, rfd, wfd, efd, timeout );
-} // uIOCluster::uSelect
-
-
-int uIOCluster::uSelect( int nfds, fd_set *rfd, fd_set *wfd, fd_set *efd, timeval *timeout ) {
-    return NBIO->uSelect( nfds, rfd, wfd, efd, timeout );
-} // uIOCluster::uSelect
+void uCluster::uCloseFD( int fd ) {
+    NBIO->uCloseFD(fd);
+} // uCluster::uCloseFD
 
 
 // Local Variables: //
-// compile-command: "dmake" //
+// compile-command: "gmake install" //
 // End: //
