@@ -1,84 +1,57 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
 // 
 // uNBIO.cc -- non-blocking IO
 // 
 // Author           : Peter A. Buhr
 // Created On       : Mon Mar  7 13:56:53 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Jun  1 16:46:04 1999
-// Update Count     : 372
+// Last Modified On : Sat Aug  7 11:21:51 2004
+// Update Count     : 491
+//
+// This  library is free  software; you  can redistribute  it and/or  modify it
+// under the terms of the GNU Lesser General Public License as published by the
+// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
+// option) any later version.
+// 
+// This library is distributed in the  hope that it will be useful, but WITHOUT
+// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
+// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
+// for more details.
+// 
+// You should  have received a  copy of the  GNU Lesser General  Public License
+// along  with this library.
 // 
 
 
 #define __U_KERNEL__
-#ifndef __U_DEBUG__
-#define NDEBUG						// turn off assert
-#endif
 
-#if defined( __linux__ )
-#define _XOPEN_SOURCE
-#define _BSD_SOURCE
-#endif
 
 #include <uC++.h>
 #include <uAssert.h>
 //#include <uDebug.h>
-#ifdef __U_DEBUG_H__
-#include <stdio.h>
-#endif __U_DEBUG_H__
 
 
-#include <string.h>					// strerror
-#include <errno.h>
+#include <cstring>					// strerror
+#include <cerrno>
 #include <sys/socket.h>
 #if defined( __linux__ )
 #include <sys/param.h>					// howmany
 #endif
 
+
 #ifndef NBBY
 #define NBBY 8
 #endif
 
 
-#if ! defined( __svr4__ ) && defined( __sun__ )
-extern "C" void bcopy(void *, void *, int);		// missing from 
-extern "C" void bzero(void *, int);			// missing from
-extern "C" int select(int, fd_set *, fd_set *, fd_set *, struct timeval *); // missing from
-#endif
-
-#if defined( __sgi__ )
-extern "C" void bzero(void *, int);			// missing from
-extern "C" int select(int, fd_set *, fd_set *, fd_set *, struct timeval *); // missing from
-#endif
-
-#if defined( __aix__ ) && defined( __ibm__ )
-extern "C" void bcopy(void *, void *, int);		// missing from 
-extern "C" void bzero(void *, int);			// missing from
-#endif
-
-#if defined( __hpux__ ) && defined( __hp__ )
-extern "C" void bcopy(void *, void *, int);		// missing from 
-#endif
-
-#if defined( __ultrix__ ) && defined( __dec__ )
-extern "C" void bcopy(void *, void *, int);		// missing from 
-extern "C" void bzero(void *, int);			// missing from
-extern "C" int select(int, fd_set *, fd_set *, fd_set *, struct timeval *); // missing from
-#endif
-
-#if defined( __gizmo__ )
-extern "C" char *strerror(int n);
-#endif
-
-
 static const int uSelectTimeOut = 1;			// how many seconds may elapse before call to select times out
 static const short uBitsPerValue[16] = { 0, 1, 1, 2, 1, 2, 2, 3, 1, 2, 2, 3, 2, 3, 3, 4 };
 
-static int uCountBits( fd_mask x ) {
+static inline int uCountBits( unsigned long int x ) {
+  if ( x == 0 ) return 0;
     int cnt;
-
     for ( cnt = 0; x > 0; x >>= 4 ) {
 	cnt += uBitsPerValue[x & 0xf];
     } // for
@@ -90,12 +63,13 @@ static int uCountBits( fd_mask x ) {
 
 
 void uNBIO::uCheckIO( uDuration delay ) {
-    unsigned int i;
+    int i;
     struct timeval timeout = delay;			// convert to timeval for select
+    int tmasks = howmany( maxFD + 1, NFDBITS );		// total number of masks in fd set
 
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uNBIO &)0x%p.uCheckIO: timeout:%d,%d\n", this, timeout.tv_sec, timeout.tv_usec );
-#endif __U_DEBUG_H__
+    uDebugPrt( "(uNBIO &)0x%p.uCheckIO: timeout:%ld,%ld\n", this, timeout.tv_sec, timeout.tv_usec );
+#endif // __U_DEBUG_H__
 
     // Make a local copy of the fd sets because the select operation destroys
     // the sets and the master information is lost.
@@ -115,42 +89,40 @@ void uNBIO::uCheckIO( uDuration delay ) {
     // "select". In such a case, the SIGALRM is treated as spurious.
     // Therefore, it is necessary to poll.
 
-    uKernelModule::uDisableInterrupts();
+    THREAD_GETMEM( uSelf )->uDisableInterrupts();
 
     int uPrevTime = uThisProcessor().uGetPreemption();	// remember previous preemption time
     if ( uPrevTime != 0 ) {				// optimize out UNIX call if possible
-	uThisProcessor().uSetContextSwitchEvent( uDuration( 0, 0 ) ); // turn off preemption or it keeps waking the UNIX processor
+	uThisProcessor().uSetContextSwitchEvent( 0 );	// turn off preemption or it keeps waking the UNIX processor
     } // if
 
     uThisCluster().uMakeProcessorIdle( uThisProcessor() );
 
 #ifdef __U_DEBUG_H__
-//    uDebugAcquire();
-//    uDebugPrt2( "(uNBIO &)0x%p.uCheckIO, lrfds:", this );
-//    for ( i = 0; i < howmany(FD_SETSIZE, NFDBITS); i += 1 ) {
-//	uDebugPrt2( "%x ", lrfds.fds_bits[i] );
-//    } // for
-//    uDebugPrt2( "\n" );
-//    uDebugPrt2( "(uNBIO &)0x%p.uCheckIO, lwfds:", this );
-//    for ( i = 0; i < howmany(FD_SETSIZE, NFDBITS); i += 1 ) {
-//	uDebugPrt2( "%x ", lwfds.fds_bits[i] );
-//    } // for
-//    uDebugPrt2( "\n" );
-//    uDebugPrt2( "(uNBIO &)0x%p.uCheckIO, lefds:", this );
-//    for ( i = 0; i < howmany(FD_SETSIZE, NFDBITS); i += 1 ) {
-//	uDebugPrt2( "%x ", lefds.fds_bits[i] );
-//    } // for
-//    uDebugPrt2( "\n" );
-//    uDebugRelease();
-#endif __U_DEBUG_H__
+#if 1
+    uDebugAcquire();
+    uDebugPrt2( "(uNBIO &)0x%p.uCheckIO, lrfds:", this );
+    for ( i = 0; i < tmasks; i += 1 ) {
+	uDebugPrt2( "%lx ", lrfds.fds_bits[i] );
+    } // for
+    uDebugPrt2( "\n" );
+    uDebugPrt2( "        (uNBIO &)0x%p.uCheckIO, lwfds:", this );
+    for ( i = 0; i < tmasks; i += 1 ) {
+	uDebugPrt2( "%lx ", lwfds.fds_bits[i] );
+    } // for
+    uDebugPrt2( "\n" );
+    uDebugPrt2( "        (uNBIO &)0x%p.uCheckIO, lefds:", this );
+    for ( i = 0; i < tmasks; i += 1 ) {
+	uDebugPrt2( "%lx ", lefds.fds_bits[i] );
+    } // for
+    uDebugPrt2( "\n" );
+    uDebugRelease();
+#endif
+#endif // __U_DEBUG_H__
 
     // Check for IO pending on any descriptors.
 
-#if defined( __hpux__ ) && defined( __hp__ )
-    uFound = select( FD_SETSIZE, (int *)&lrfds, (int *)&lwfds, (int *)&lefds, &timeout );
-#else
-    uFound = select( FD_SETSIZE, &lrfds, &lwfds, &lefds, &timeout );
-#endif
+    uFound = ::select( maxFD + 1, &lrfds, &lwfds, &lefds, &timeout );
 
     uThisCluster().uMakeProcessorActive( uThisProcessor() );
 
@@ -158,44 +130,51 @@ void uNBIO::uCheckIO( uDuration delay ) {
 	uThisProcessor().uSetContextSwitchEvent( uPrevTime ); // reset processor preemption time
     } // if
 
-    uKernelModule::uEnableInterrupts();			// does necessary roll forward
+    THREAD_GETMEM( uSelf )->uEnableInterrupts();	// does necessary roll forward
 
 #ifdef __U_DEBUG_H__
-    uDebugPrt( "(uNBIO &)0x%p.uCheckIO: select returns: found %d, timeout:%d,%d\n", this, uFound, timeout.tv_sec, timeout.tv_usec );
-#endif __U_DEBUG_H__
+    uDebugPrt( "(uNBIO &)0x%p.uCheckIO: select returns: found %d, timeout:%ld,%ld\n", this, uFound, timeout.tv_sec, timeout.tv_usec );
+#endif // __U_DEBUG_H__
 
     if ( uFound > 0 ) {					// I/O has occurred ?
-
 #ifdef __U_DEBUG_H__
-//	uDebugAcquire();
-//	uDebugPrt2( "(uNBIO &)0x%p.uCheckIO: found %d pending IO operations\n", this, uFound );
-//	uDebugPrt2( "(uNBIO &)0x%p.uCheckIO, lrfds:", this );
-//	for ( i = 0; i < howmany(FD_SETSIZE, NFDBITS); i += 1 ) {
-//	    uDebugPrt2( "%x ", lrfds.fds_bits[i] );
-//	} // for
-//	uDebugPrt2( "\n" );
-//	uDebugPrt2( "(uNBIO &)0x%p.uCheckIO, lwfds:", this );
-//	for ( i = 0; i < howmany(FD_SETSIZE, NFDBITS); i += 1 ) {
-//	    uDebugPrt2( "%x ", lwfds.fds_bits[i] );
-//	} // for
-//	uDebugPrt2( "\n" );
-//	uDebugPrt2( "(uNBIO &)0x%p.uCheckIO, lefds:", this );
-//	for ( i = 0; i < howmany(FD_SETSIZE, NFDBITS); i += 1 ) {
-//	    uDebugPrt2( "%x ", lefds.fds_bits[i] );
-//	} // for
-//	uDebugPrt2( "\n" );
-//	uDebugRelease();
-#endif __U_DEBUG_H__
+	uDebugPrt( "(uNBIO &)0x%p.uCheckIO: found %d pending IO operations\n", this, uFound );
+#if 1
+	uDebugAcquire();
+	uDebugPrt2( "(uNBIO &)0x%p.uCheckIO, lrfds:", this );
+	for ( i = 0; i < tmasks; i += 1 ) {
+	    uDebugPrt2( "%lx ", lrfds.fds_bits[i] );
+	} // for
+	uDebugPrt2( "\n" );
+	uDebugPrt2( "        (uNBIO &)0x%p.uCheckIO, lwfds:", this );
+	for ( i = 0; i < tmasks; i += 1 ) {
+	    uDebugPrt2( "%lx ", lwfds.fds_bits[i] );
+	} // for
+	uDebugPrt2( "\n" );
+	uDebugPrt2( "        (uNBIO &)0x%p.uCheckIO, lefds:", this );
+	for ( i = 0; i < tmasks; i += 1 ) {
+	    uDebugPrt2( "%lx ", lefds.fds_bits[i] );
+	} // for
+	uDebugPrt2( "\n" );
+	uDebugRelease();
+#endif
+#endif // __U_DEBUG_H__
 
 	// Remove the ready I/O fds from the master lists as these I/O
 	// operations have completed.
 
-	for ( i = 0; i < howmany( FD_SETSIZE, NFDBITS ); i += 1 ) {
+	for ( i = 0; i < tmasks; i += 1 ) {
 	    uRFDs.fds_bits[i] ^= lrfds.fds_bits[i];
 	    uWFDs.fds_bits[i] ^= lwfds.fds_bits[i];
 	    uEFDs.fds_bits[i] ^= lefds.fds_bits[i];
 	} // for
 
+	// Check if maxFD needs to be reset.
+
+	if ( ! ( FD_ISSET( maxFD, &uRFDs ) || FD_ISSET( maxFD, &uWFDs ) || FD_ISSET( maxFD, &uEFDs ) ) ) {  
+	    setMaxFD();
+	} // if
+
 	// Check to see which tasks are waiting for ready I/O operations and
 	// wake them.
 
@@ -205,20 +184,20 @@ void uNBIO::uCheckIO( uDuration delay ) {
 	    cnt = 0;
 	    if ( p->fdType == uNBIOnode::singleFd ) {	// single fd
 #ifdef __U_DEBUG_H__
-		uDebugPrt( "(uNBIO &)0x%p.uCheckIO: found task waiting on single fd %d with mask 0x%x\n",
-			   this, p->smfd.sfd.fd, *p->smfd.sfd.uRWE );
-#endif __U_DEBUG_H__
+		uDebugPrt( "(uNBIO &)0x%p.uCheckIO: found task %.256s (0x%p) waiting on single fd %d with mask 0x%x\n",
+			   this, p->uPendingTask->uGetName(), p->uPendingTask, p->smfd.sfd.fd, *p->smfd.sfd.uRWE );
+#endif // __U_DEBUG_H__
 		int temp = 0;
-		if ( (*p->smfd.sfd.uRWE & uIOCluster::uReadSelect) && FD_ISSET( p->smfd.sfd.fd, &lrfds ) ) {
-		    temp |= uIOCluster::uReadSelect;
+		if ( (*p->smfd.sfd.uRWE & uCluster::uReadSelect) && FD_ISSET( p->smfd.sfd.fd, &lrfds ) ) {
+		    temp |= uCluster::uReadSelect;
 		    cnt += 1;
 		} // if
-		if ( (*p->smfd.sfd.uRWE & uIOCluster::uWriteSelect ) && FD_ISSET( p->smfd.sfd.fd, &lwfds ) ) {
-		    temp |= uIOCluster::uWriteSelect;
+		if ( (*p->smfd.sfd.uRWE & uCluster::uWriteSelect ) && FD_ISSET( p->smfd.sfd.fd, &lwfds ) ) {
+		    temp |= uCluster::uWriteSelect;
 		    cnt += 1;
 		} // if
-		if ( (*p->smfd.sfd.uRWE & uIOCluster::uExceptSelect) && FD_ISSET( p->smfd.sfd.fd, &lefds ) ) {
-		    temp |= uIOCluster::uExceptSelect;
+		if ( (*p->smfd.sfd.uRWE & uCluster::uExceptSelect) && FD_ISSET( p->smfd.sfd.fd, &lefds ) ) {
+		    temp |= uCluster::uExceptSelect;
 		    cnt += 1;
 		} // if
 		if ( cnt != 0 ) {			// reset user mask only if I/O available
@@ -226,65 +205,114 @@ void uNBIO::uCheckIO( uDuration delay ) {
 		} // if
 	    } else {					// multiple fds
 #ifdef __U_DEBUG_H__
-		uDebugPrt( "(uNBIO &)0x%p.uCheckIO: found task waiting for multiple fd\n", this );
-#endif __U_DEBUG_H__
+		uDebugPrt( "(uNBIO &)0x%p.uCheckIO: found task %.256s (0x%p) waiting for multiple fd, nfd:%ld\n",
+			   this, p->uPendingTask->uGetName(), p->uPendingTask, p->smfd.mfd.uNFDs );
+#endif // __U_DEBUG_H__
 		fd_set tfds;				// temporary masks to construct result mask
-		int tcnt;
-		int nbytes = ( p->smfd.mfd.uNFDs + ( NBBY - 1 ) ) / NBBY;
+		int nmasks = howmany( p->smfd.mfd.uNFDs, NFDBITS );
 
-		if ( p->smfd.mfd.uRFDs ) {		// non-zero user mask ?
-		    FD_ZERO( &tfds );
-		    tcnt = 0;
-		    for ( i = 0; i < howmany( p->smfd.mfd.uNFDs, NFDBITS ); i += 1 ) {
-			tfds.fds_bits[i] = p->smfd.mfd.uRFDs->fds_bits[i] & lrfds.fds_bits[i];
-			tcnt += uCountBits( tfds.fds_bits[i] );
-		    } // for
-		    if ( tcnt != 0 ) {			// reset user mask only if I/O available
-#ifdef __svr4__
-			memcpy( p->smfd.mfd.uRFDs, &tfds, nbytes );
-#else
-			bcopy( &tfds, p->smfd.mfd.uRFDs, nbytes );
-#endif
-			cnt += tcnt;
-		    } // if
+		for ( i = 0; i < nmasks - 1; i += 1 ) {	// fd bits of interest
+		    tfds.fds_bits[i] = 0;
+		} // for
+
+		int shift = p->smfd.mfd.uNFDs % NFDBITS;
+		if ( shift == 0 ) {
+		    tfds.fds_bits[nmasks - 1] = 0;
+		} else {
+		    tfds.fds_bits[nmasks - 1] = -1L << shift;
 		} // if
-		if ( p->smfd.mfd.uWFDs ) {		// non-zero user mask ?
-		    FD_ZERO( &tfds );
-		    tcnt = 0;
-		    for ( i = 0; i < howmany( p->smfd.mfd.uNFDs, NFDBITS ); i += 1 ) {
-			tfds.fds_bits[i] = p->smfd.mfd.uWFDs->fds_bits[i] & lwfds.fds_bits[i];
-			tcnt += uCountBits( tfds.fds_bits[i] );
-		    } // for
-		    if ( tcnt != 0 ) {			// reset user mask only if I/O available
-#ifdef __svr4__
-			memcpy( p->smfd.mfd.uWFDs, &tfds, nbytes );
-#else
-			bcopy( &tfds, p->smfd.mfd.uWFDs, nbytes );
+#ifdef __U_DEBUG_H__
+#if 1
+		uDebugAcquire();
+		uDebugPrt2( "(uNBIO &)0x%p.uCheckIO, tfds:", this );
+		for ( i = 0; i < nmasks; i += 1 ) {
+		    uDebugPrt2( "%lx ", tfds.fds_bits[i] );
+		} // for
+		uDebugPrt2( "\n" );
+		uDebugRelease();
 #endif
-			cnt += tcnt;
-		    } // if
-		} // if
-		if ( p->smfd.mfd.uEFDs ) {		// non-zero user mask ?
-		    FD_ZERO( &tfds );
-		    tcnt = 0;
-		    for ( i = 0; i < howmany( p->smfd.mfd.uNFDs, NFDBITS ); i += 1 ) {
-			tfds.fds_bits[i] = p->smfd.mfd.uEFDs->fds_bits[i] & lefds.fds_bits[i];
-			tcnt += uCountBits( tfds.fds_bits[i] );
+#endif // __U_DEBUG_H__
+#ifdef __U_DEBUG_H__
+#if 1
+		uDebugAcquire();
+		if ( p->smfd.mfd.uRFDs != NULL ) {
+		    uDebugPrt2( "(uNBIO &)0x%p.uCheckIO, uRFDs:", this );
+		    for ( i = 0; i < tmasks; i += 1 ) {
+			uDebugPrt2( "%lx ", p->smfd.mfd.uRFDs->fds_bits[i] );
 		    } // for
-		    if ( tcnt != 0 ) {			// reset user mask only if I/O available
-#ifdef __svr4__
-			memcpy( p->smfd.mfd.uEFDs, &tfds, nbytes );
-#else
-			bcopy( &tfds, p->smfd.mfd.uEFDs, nbytes );
-#endif
-			cnt += tcnt;
-		    } // if
+		    uDebugPrt2( "\n" );
 		} // if
+		if ( p->smfd.mfd.uWFDs != NULL ) {
+		    uDebugPrt2( "        (uNBIO &)0x%p.uCheckIO, uWFDs:", this );
+		    for ( i = 0; i < tmasks; i += 1 ) {
+			uDebugPrt2( "%lx ", p->smfd.mfd.uWFDs->fds_bits[i] );
+		    } // for
+		    uDebugPrt2( "\n" );
+		} // if
+		if ( p->smfd.mfd.uEFDs != NULL ) {
+		    uDebugPrt2( "        (uNBIO &)0x%p.uCheckIO, uEFDs:", this );
+		    for ( i = 0; i < tmasks; i += 1 ) {
+			uDebugPrt2( "%lx ", p->smfd.mfd.uEFDs->fds_bits[i] );
+		    } // for
+		    uDebugPrt2( "\n" );
+		} // if
+		uDebugRelease();
+#endif
+#endif // __U_DEBUG_H__
+		if ( p->smfd.mfd.uRFDs ) {		// non-null user mask ?
+		    for ( i = 0; i < nmasks; i += 1 ) {
+			fd_mask temp = p->smfd.mfd.uRFDs->fds_bits[i] & ( tfds.fds_bits[i] | lrfds.fds_bits[i] );
+			p->smfd.mfd.uRFDs->fds_bits[i] = temp;
+			cnt += uCountBits( temp );
+		    } // for
+		} // if
+		if ( p->smfd.mfd.uWFDs ) {		// non-null user mask ?
+		    for ( i = 0; i < nmasks; i += 1 ) {
+			fd_mask temp = p->smfd.mfd.uWFDs->fds_bits[i] & ( tfds.fds_bits[i] | lwfds.fds_bits[i] );
+			p->smfd.mfd.uWFDs->fds_bits[i] = temp;
+			cnt += uCountBits( temp );
+		    } // for
+		} // if
+		if ( p->smfd.mfd.uEFDs ) {		// non-null user mask ?
+		    for ( i = 0; i < nmasks; i += 1 ) {
+			fd_mask temp = p->smfd.mfd.uEFDs->fds_bits[i] & ( tfds.fds_bits[i] | lefds.fds_bits[i] );
+			p->smfd.mfd.uEFDs->fds_bits[i] = temp;
+			cnt += uCountBits( temp );
+		    } // for
+		} // if
+#ifdef __U_DEBUG_H__
+#if 1
+		uDebugPrt( "(uNBIO &)0x%p.uCheckIO, cnt:%d\n", this, cnt );
+		uDebugAcquire();
+		if ( p->smfd.mfd.uRFDs != NULL ) {
+		    uDebugPrt2( "(uNBIO &)0x%p.uCheckIO, uRFDs:", this );
+		    for ( i = 0; i < tmasks; i += 1 ) {
+			uDebugPrt2( "%lx ", p->smfd.mfd.uRFDs->fds_bits[i] );
+		    } // for
+		    uDebugPrt2( "\n" );
+		} // if
+		if ( p->smfd.mfd.uWFDs != NULL ) {
+		    uDebugPrt2( "        (uNBIO &)0x%p.uCheckIO, uWFDs:", this );
+		    for ( i = 0; i < tmasks; i += 1 ) {
+			uDebugPrt2( "%lx ", p->smfd.mfd.uWFDs->fds_bits[i] );
+		    } // for
+		    uDebugPrt2( "\n" );
+		} // if
+		if ( p->smfd.mfd.uEFDs != NULL ) {
+		    uDebugPrt2( "        (uNBIO &)0x%p.uCheckIO, uEFDs:", this );
+		    for ( i = 0; i < tmasks; i += 1 ) {
+			uDebugPrt2( "%lx ", p->smfd.mfd.uEFDs->fds_bits[i] );
+		    } // for
+		    uDebugPrt2( "\n" );
+		} // if
+		uDebugRelease();
+#endif
+#endif // __U_DEBUG_H__
 	    } // if
 	    if ( cnt != 0 || p->uTimedout ) {		// I/O completed for this task or timed out ?
 #ifdef __U_DEBUG_H__
-		uDebugPrt( "(uNBIO &)0x%p.uCheckIO: removing node 0x%p\n", this, p );
-#endif __U_DEBUG_H__
+		uDebugPrt( "(uNBIO &)0x%p.uCheckIO: removing node 0x%p, cnt:%d, uTimedout:%d\n", this, p, cnt, p->uTimedout );
+#endif // __U_DEBUG_H__
 		uPendingIO.uRemove( p );		// remove node from list of waiting tasks
 		p->nfds = cnt;				// set return value
 		uSignal p->uPending;			// wake up waiting task (empty for IOPoller)
@@ -293,7 +321,7 @@ void uNBIO::uCheckIO( uDuration delay ) {
     } else if ( uFound == 0 ) {				// time limit expired, no IO is ready
 #ifdef __U_DEBUG_H__
 	uDebugPrt( "(uNBIO &)0x%p.uCheckIO: time limit expired, errno:%d\n", this, errno );
-#endif __U_DEBUG_H__
+#endif // __U_DEBUG_H__
 	// Check for timed out IO
 
 	uNBIOnode *p;
@@ -301,7 +329,7 @@ void uNBIO::uCheckIO( uDuration delay ) {
 	    if ( p->uTimedout ) {			// timed out waiting for I/O for this task ?
 #ifdef __U_DEBUG_H__
 		uDebugPrt( "(uNBIO &)0x%p.uCheckIO: removing node 0x%p\n", this, p );
-#endif __U_DEBUG_H__
+#endif // __U_DEBUG_H__
 		uPendingIO.uRemove( p );		// remove node from list of waiting tasks
 		p->nfds = 0;				// set return value
 		uSignal p->uPending;			// wake up waiting task (empty for IOPoller)
@@ -330,28 +358,28 @@ void uNBIO::uCheckIO( uDuration delay ) {
 		uSignal p->uPending;			// wake up waiting task (empty for IOPoller)
 	    } // for
 	} else {
-	    uAbort( "(uNBIO &)0x%p.uCheckIO() : internal error, error(%d): %s", this, errno, strerror( errno ) );
+	    uAbort( "(uNBIO &)0x%p.uCheckIO() : internal error, error(%d) %s.", this, errno, strerror( errno ) );
 	} // if
     } // if
 } // uNBIO::uCheckIO
 
 
-inline bool uNBIO::uCheckPoller( uNBIOnode &uNode ) {
+bool uNBIO::uCheckPoller( uNBIOnode &uNode ) {
     uPendingIO.uAddTail( &uNode );			// node is removed by IOPoller
 
     // If this is the first task to register interest, this task is nominated
     // as the IO poller task.
 
-    if ( uIOPoller == (uBaseTask *)0 ) {
+    if ( uIOPoller == NULL ) {
 	uIOPoller = &uThisTask();			// make this task the poller
 #ifdef __U_DEBUG_H__
-	uDebugPrt( "(uNBIO &)0x%p.uCheckPoller, set poller task 0x%p (%.256s)\n", this, uIOPoller, uIOPoller->uGetName() );
-#endif __U_DEBUG_H__
+	uDebugPrt( "(uNBIO &)0x%p.uCheckPoller, set poller task %.256s (0x%p)\n", this, uIOPoller->uGetName(), uIOPoller );
+#endif // __U_DEBUG_H__
 	return true;
     } else {
 #ifdef __U_DEBUG_H__
-	uDebugPrt( "(uNBIO &)0x%p.uCheckPoller, blocking non-poller I/O task 0x%p (%.256s))\n", this, &uThisTask(), uThisTask().uGetName() );
-#endif __U_DEBUG_H__
+	uDebugPrt( "(uNBIO &)0x%p.uCheckPoller, blocking non-poller I/O task %.256s (0x%p))\n", this, uThisTask().uGetName(), &uThisTask() );
+#endif // __U_DEBUG_H__
 	// This is not the poller task so add it to the list of tasks waiting
 	// for IO events.  It is woken when an IO event is ready or nominated
 	// as the poller.
@@ -366,6 +394,59 @@ inline bool uNBIO::uCheckPoller( uNBIOnode &uNode ) {
     } // if
 } // uNBIO::uCheckPoller
 
+ 
+void uNBIO::setMaxFD(){
+    int prevMax = maxFD;
+    maxFD = 0;
+#if 1
+    unsigned long combined;
+
+    // This code makes assumptions about the implemenetation of fd_set.  Namely
+    // that each chunk is an unsigned long and that the rightmost bit contains
+    // the lowest numbered fd.
+    _STATIC_ASSERT_( (sizeof(combined) * 8) == NFDBITS );
+    
+    // Search backwards from previous max
+    for ( int i = howmany( prevMax, NFDBITS ); i >= 0 ; i -= 1 ) {
+	if ( uRFDs.fds_bits[i] || uWFDs.fds_bits[i] || uEFDs.fds_bits[i] ) {
+	    // combined is guaranteed to have at least one bit set
+	    combined = (uRFDs.fds_bits[i] | uWFDs.fds_bits[i] | uEFDs.fds_bits[i]);
+	    int j;
+	    for ( j = NFDBITS - 1; ! (combined & ( 1ul << j ) ); j -= 1 );
+	    maxFD = j + i * NFDBITS ;
+	    break;
+	} // if
+    } // for
+#else
+    // This version can run faster.  Consider if maxFD was 35 and is now 33.
+    // Only two iterations are required (two because it starts at the previous
+    // max, it could start at previous max - 1).  In the algorithm above, one
+    // check confirms that the chunk is the same and then 30 iterations are
+    // required to get from bit 31 to 1.  The algorithm above is significantly
+    // better if the difference between the previous and new max is large,
+    // i.e., more that 2 chunks.  An optimization might be to fold this
+    // algorithm into the above algorithm and use it under certain conditions.
+
+    for (int i = prevMax; i >= 0; i -= 1 ) {
+	if ( FD_ISSET( i, &uRFDs ) || FD_ISSET( i, &uWFDs ) || FD_ISSET( i, &uEFDs ) ) {
+	    maxFD = i;
+	    break;
+	} // if
+    } // for
+#endif
+} // uNBIO::setMaxFD
+
+
+void uNBIO::uCloseFD( int fd ) {
+    FD_CLR( fd, &uRFDs );
+    FD_CLR( fd, &uWFDs );
+    FD_CLR( fd, &uEFDs );
+    
+    if ( fd == maxFD ) {				// increase maxFD if necessary
+	setMaxFD();
+    } // if
+} // uNBIO::uCloseFD
+
 
 bool uNBIO::uPollIO( uNBIOnode &uNode ) {
     // If there are other tasks on the ready queue of this cluster that can
@@ -384,7 +465,7 @@ bool uNBIO::uPollIO( uNBIOnode &uNode ) {
     // uOkToSelect is set in the uniprocessor kernel when *all* clusters have
     // empty ready queues.
     if ( uOkToSelect ) {
-#endif __U_MULTI__
+#endif // __U_MULTI__
 	uTime nexttime;
 	uDuration timeout;
 
@@ -418,12 +499,12 @@ bool uNBIO::uPollIO( uNBIOnode &uNode ) {
 	    uNBIOnode *p = uPendingIO.uHead();		// node from list of waiting tasks
 	    uIOPoller = p->uPendingTask;		// next poller task
 #ifdef __U_DEBUG_H__
-	    uDebugPrt( "(uNBIO &)0x%p.uPollIO, poller 0x%p (%.256s) nominating task 0x%p (%.256s) to be next poller\n",
-		       this, &uThisTask(), uThisTask().uGetName(), uIOPoller, uIOPoller->uGetName() );
-#endif __U_DEBUG_H__
+	    uDebugPrt( "(uNBIO &)0x%p.uPollIO, poller %.256s (0x%p) nominating task %.256s (0x%p) to be next poller\n",
+		       this, uThisTask().uGetName(), &uThisTask(), uIOPoller->uGetName(), uIOPoller );
+#endif // __U_DEBUG_H__
 	    uSignal p->uPending;			// wake up waiting task
 	} else {
-	    uIOPoller = (uBaseTask *)0;
+	    uIOPoller = NULL;
 	} // if
 	return false;
     } else {
@@ -433,28 +514,36 @@ bool uNBIO::uPollIO( uNBIOnode &uNode ) {
 
 
 bool uNBIO::uInitSfd( uNBIOnode &uNode ) {
+    if ( uNode.smfd.sfd.fd > maxFD ) {			// increase maxFD if necessary
+	maxFD = uNode.smfd.sfd.fd;
+    } // if
+
     // set the appropriate fd bit in the master fd mask
-    if ( *uNode.smfd.sfd.uRWE & uIOCluster::uReadSelect ) FD_SET( uNode.smfd.sfd.fd, &uRFDs );
-    if ( *uNode.smfd.sfd.uRWE & uIOCluster::uWriteSelect ) FD_SET( uNode.smfd.sfd.fd, &uWFDs );
-    if ( *uNode.smfd.sfd.uRWE & uIOCluster::uExceptSelect ) FD_SET( uNode.smfd.sfd.fd, &uEFDs );
+    if ( *uNode.smfd.sfd.uRWE & uCluster::uReadSelect ) FD_SET( uNode.smfd.sfd.fd, &uRFDs );
+    if ( *uNode.smfd.sfd.uRWE & uCluster::uWriteSelect ) FD_SET( uNode.smfd.sfd.fd, &uWFDs );
+    if ( *uNode.smfd.sfd.uRWE & uCluster::uExceptSelect ) FD_SET( uNode.smfd.sfd.fd, &uEFDs );
 
 #ifdef __U_DEBUG_H__
     uDebugPrt( "(uNBIO &)0x%p.uInitSfd, adding node 0x%p\n", this, &uNode );
-#endif __U_DEBUG_H__
+#endif // __U_DEBUG_H__
 
     return uCheckPoller( uNode );
 } // uNBIO::uInitSfd
 
 
 bool uNBIO::uInitSfd( uNBIOnode &uNode, uEventNode &uTimeoutEvent, uProcessor &proc ) {
+    if ( uNode.smfd.sfd.fd > maxFD ) {			// increase maxFD if necessary
+	maxFD = uNode.smfd.sfd.fd;
+    } // if
+
     // set the appropriate fd bit in the master fd mask
-    if ( *uNode.smfd.sfd.uRWE & uIOCluster::uReadSelect ) FD_SET( uNode.smfd.sfd.fd, &uRFDs );
-    if ( *uNode.smfd.sfd.uRWE & uIOCluster::uWriteSelect ) FD_SET( uNode.smfd.sfd.fd, &uWFDs );
-    if ( *uNode.smfd.sfd.uRWE & uIOCluster::uExceptSelect ) FD_SET( uNode.smfd.sfd.fd, &uEFDs );
+    if ( *uNode.smfd.sfd.uRWE & uCluster::uReadSelect ) FD_SET( uNode.smfd.sfd.fd, &uRFDs );
+    if ( *uNode.smfd.sfd.uRWE & uCluster::uWriteSelect ) FD_SET( uNode.smfd.sfd.fd, &uWFDs );
+    if ( *uNode.smfd.sfd.uRWE & uCluster::uExceptSelect ) FD_SET( uNode.smfd.sfd.fd, &uEFDs );
 
 #ifdef __U_DEBUG_H__
     uDebugPrt( "(uNBIO &)0x%p.uInitSfd, adding node 0x%p\n", this, &uNode );
-#endif __U_DEBUG_H__
+#endif // __U_DEBUG_H__
 
     proc.uEvents->uAddEvent( uTimeoutEvent, proc );
 
@@ -465,11 +554,13 @@ bool uNBIO::uInitSfd( uNBIOnode &uNode, uEventNode &uTimeoutEvent, uProcessor &p
 uNBIO::uNBIO() {
 #ifdef __U_DEBUG_H__
     uDebugPrt( "(uNBIO &)0x%p.uNBIO\n", this );
-#endif __U_DEBUG_H__
-    uIOPoller = (uBaseTask *)0;				// no task is first yet
+#endif // __U_DEBUG_H__
     FD_ZERO( &uRFDs );					// clear the read set
     FD_ZERO( &uWFDs );					// clear the write set
     FD_ZERO( &uEFDs );					// clear the exceptional set
+    maxFD = 0;						// all masks are clear
+    uIOPoller = NULL;					// no task is first yet
+    uOkToSelect = false;
 } // uNBIO::uNBIO
 
 
@@ -478,12 +569,25 @@ uNBIO::~uNBIO() {
 
 
 int uNBIO::uSelect( int fd, int &rwe, timeval *timeout ) {
+#ifdef __U_DEBUG_H__
+#if 1
+    uDebugAcquire();
+    uDebugPrt2( "(uNBIO &)0x%p.uSelect1, fd:%d, rwe:%x", this, fd, rwe );
+    if ( timeout != NULL ) {
+	uDebugPrt2( ", timeout:%ld.%ld\n", timeout->tv_sec, timeout->tv_usec );
+    } else {
+	uDebugPrt2( "\n" );
+    } // if
+    uDebugRelease();
+#endif
+#endif // __U_DEBUG_H__
+
 #ifdef __U_DEBUG__
     if ( fd < 0 || FD_SETSIZE <= fd ) {
 	uAbort( ": attempt to select on file descriptor %d, which exceeds range 0-%d.",
-	       fd, FD_SETSIZE - 1 );
+		fd, FD_SETSIZE - 1 );
     } // if
-#endif __U_DEBUG__
+#endif // __U_DEBUG__
 
     uNBIOnode uNode;
     uNode.nfds = 0;
@@ -524,11 +628,18 @@ int uNBIO::uSelect( int fd, int &rwe, timeval *timeout ) {
 	} // if
     } // if
 
+#ifdef __U_DEBUG_H__
+    uDebugPrt( "(uNBIO &)0x%p.uSelect1, exits, cnt:%d\n", this, uNode.nfds );
+#endif // __U_DEBUG_H__
     return uNode.nfds;
 } // uNBIO::uSelect
 
 
 bool uNBIO::uInitMfds( fd_mask nfds, uNBIOnode &uNode ) {
+    if ( nfds > maxFD ) {				// increase maxFD if necessary
+	maxFD = nfds - 1;
+    } // if
+
     // set the appropriate fd bits in the master fd mask
     for ( unsigned int i = 0; i < howmany( nfds, NFDBITS ); i += 1 ) {
 	// mask pointers can be NULL => nothing in that mask
@@ -539,13 +650,17 @@ bool uNBIO::uInitMfds( fd_mask nfds, uNBIOnode &uNode ) {
 
 #ifdef __U_DEBUG_H__
     uDebugPrt( "(uNBIO &)0x%p.uInitMfds, adding node 0x%p\n", this, &uNode );
-#endif __U_DEBUG_H__
+#endif // __U_DEBUG_H__
 
     return uCheckPoller( uNode );
 } // uNBIO::uInitMfds
 
      
 bool uNBIO::uInitMfds( fd_mask nfds, uNBIOnode &uNode, uEventNode &uTimeoutEvent, uProcessor &proc ) {
+    if ( nfds > maxFD ) {				// increase maxFD if necessary
+	maxFD = nfds - 1;
+    } // if
+
     // set the appropriate fd bits in the master fd mask
     for ( unsigned int i = 0; i < howmany( nfds, NFDBITS ); i += 1 ) {
 	// mask pointers can be NULL => nothing in that mask
@@ -556,7 +671,7 @@ bool uNBIO::uInitMfds( fd_mask nfds, uNBIOnode &uNode, uEventNode &uTimeoutEvent
 
 #ifdef __U_DEBUG_H__
     uDebugPrt( "(uNBIO &)0x%p.uInitMfds, adding node 0x%p\n", this, &uNode );
-#endif __U_DEBUG_H__
+#endif // __U_DEBUG_H__
 
     proc.uEvents->uAddEvent( uTimeoutEvent, proc );
 
@@ -565,12 +680,46 @@ bool uNBIO::uInitMfds( fd_mask nfds, uNBIOnode &uNode, uEventNode &uTimeoutEvent
 
 
 int uNBIO::uSelect( fd_mask nfds, fd_set *rfds, fd_set *wfds, fd_set *efds, timeval *timeout ) {
+#ifdef __U_DEBUG_H__
+#if 1
+    int i;
+    int tmasks = howmany( FD_SETSIZE, NFDBITS );	// total number of masks in fd set
+    uDebugPrt( "(uNBIO &)0x%p.uSelect2, nfds:%ld\n", this, nfds );
+    uDebugAcquire();
+    if ( rfds != NULL ) {
+	uDebugPrt2( "(uNBIO &)0x%p.uSelect2, rfds:", this );
+	for ( i = 0; i < tmasks; i += 1 ) {
+	    uDebugPrt2( "%lx ", rfds->fds_bits[i] );
+	} // for
+	uDebugPrt2( "\n" );
+    } // if
+    if ( wfds != NULL ) {
+	uDebugPrt2( "        (uNBIO &)0x%p.uSelect2, wfds:", this );
+	for ( i = 0; i < tmasks; i += 1 ) {
+	    uDebugPrt2( "%lx ", wfds->fds_bits[i] );
+	} // for
+	uDebugPrt2( "\n" );
+    } // if
+    if ( efds != NULL ) {
+	uDebugPrt2( "        (uNBIO &)0x%p.uSelect2, efds:", this );
+	for ( i = 0; i < tmasks; i += 1 ) {
+	    uDebugPrt2( "%lx ", efds->fds_bits[i] );
+	} // for
+	uDebugPrt2( "\n" );
+    } // if
+    if ( timeout != NULL ) {
+	uDebugPrt2( "        (uNBIO &)0x%p.uSelect2, timeout:%ld.%ld\n", this, timeout->tv_sec, timeout->tv_usec );
+    } // if
+    uDebugRelease();
+#endif
+#endif // __U_DEBUG_H__
+
 #ifdef __U_DEBUG__
     if ( nfds < 1 || FD_SETSIZE < nfds ) {
-	uAbort( ": attempt to select with a file descriptor set size of %d, which exceeds range 0-%d.",
-	       nfds, FD_SETSIZE );
+	uAbort( ": attempt to select with a file descriptor set size of %ld, which exceeds range 0-%d.",
+		(long int)nfds, FD_SETSIZE );
     } // if
-#endif __U_DEBUG__
+#endif // __U_DEBUG__
 
     uNBIOnode uNode;
     uNode.nfds = 0;
@@ -613,10 +762,13 @@ int uNBIO::uSelect( fd_mask nfds, fd_set *rfds, fd_set *wfds, fd_set *efds, time
 	} // if
     } // if
 
+#ifdef __U_DEBUG_H__
+    uDebugPrt( "(uNBIO &)0x%p.uSelect2, exits, cnt:%d\n", this, uNode.nfds );
+#endif // __U_DEBUG_H__
     return uNode.nfds;
 } // uNBIO::uSelect
 
-
-// Local Variables:
-// compile-command: "dmake"
-// End:
+ 
+// Local Variables: //
+// compile-command: "gmake install" //
+// End: //
