@@ -1,14 +1,27 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr 1994
 // 
 // uSocket.h -- Nonblocking UNIX Socket I/O
 // 
 // Author           : Peter Buhr
 // Created On       : Tue Mar 29 17:04:36 1994
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Sun May 23 16:23:33 1999
-// Update Count     : 207
+// Last Modified On : Sun Aug  8 08:18:46 2004
+// Update Count     : 295
+//
+// This  library is free  software; you  can redistribute  it and/or  modify it
+// under the terms of the GNU Lesser General Public License as published by the
+// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
+// option) any later version.
+// 
+// This library is distributed in the  hope that it will be useful, but WITHOUT
+// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
+// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
+// for more details.
+// 
+// You should  have received a  copy of the  GNU Lesser General  Public License
+// along  with this library.
 // 
 
 
@@ -16,34 +29,26 @@
 #define __U_SOCKET_H__
 
 
-//#include <uDebug.h>
 #include <uFile.h>
-#include <uNetwork.h>
+//#include <uDebug.h>
 
 
 #pragma __U_NOT_USER_CODE__
 
 
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <sys/un.h>
-#include <stdio.h>					// FILENAME_MAX
+#include <cstdio>
 #include <netdb.h>					// MAXHOSTNAMELEN on Solaris
-
-#ifndef FILENAME_MAX
-#define FILENAME_MAX 1024
-#endif
+#include <sys/param.h>					// MAXHOSTNAMELEN on BSD
 
 
 //######################### uSocket #########################
 
 
 class uSocket {
-    friend class uSocketServer;				// access: access, locn, uSocket, ~uSocket
-    friend class uSocketAccept;				// access: access, locn
-    friend class uSocketClient;				// access: access, locn, uSocket, ~uSocket
+    friend class uSocketServer;				// access: access, uSocket, ~uSocket
+    friend class uSocketAccept;				// access: access
+    friend class uSocketClient;				// access: access, uSocket, ~uSocket
 
-    uIOlocn locn;
     uIOaccess access;
 
     const int domain, type, protocol;			// copies for information purposes
@@ -53,7 +58,6 @@ class uSocket {
 
     void uCreateSocket( int domain, int type, int protocol );
     uSocket( int domain, int type, int protocol );	// creation restricted to friends
-    uSocket( uIOCluster &cluster, int domain, int type, int protocol ); // creation restricted to friends
     virtual ~uSocket();
   public:
     uDualEvent uFailure;
@@ -68,28 +72,37 @@ class uSocket {
 
 
 class uSocketIO : public uFileIO {
-    uMutex int me_send( char *buf, int len, int flags );
-    uMutex int me_sendto( char *buf, int len, int flags, void *to, int tolen );
-    uMutex int me_sendmsg( const msghdr *msg, int flags );
-    uMutex int me_recv( char *buf, int len, int flags );
-    uMutex int me_recvfrom( char *buf, int len, int flags, void *from, int *fromlen );
-    uMutex int me_recvmsg( msghdr *msg, int flags );
+    int _send( char *buf, int len, int flags );
+    int _sendto( char *buf, int len, int flags, struct sockaddr *to, socklen_t tolen );
+    int _sendmsg( const struct msghdr *msg, int flags );
+    int _recv( char *buf, int len, int flags );
+    int _recvfrom( char *buf, int len, int flags, struct sockaddr *from, socklen_t *fromlen );
+    int _recvmsg( struct msghdr *msg, int flags );
   protected:
-    sockaddr *saddr;
-    int saddrlen;
+    struct inetAddr : sockaddr_in {
+	int code;
+	char _name[MAXHOSTNAMELEN+1];
+	void getinetAddr( unsigned short port, const char *name );
+	inetAddr( unsigned short port, const char *name = "" );
+    }; // inetAddr
 
-    uSocketIO( uIOlocn &io, uIOaccess &acc, sockaddr *saddr, int saddrlen );
+    struct sockaddr *saddr;				// default send/receive address
+    socklen_t saddrlen;					// size of send address
+    socklen_t baddrlen;					// size of address buffer (UNIX/INET)
+
+    uSocketIO( uIOaccess &acc, struct sockaddr *saddr );
   public:
-    uMutex int getsockname( sockaddr *name, int *len );
-    uMutex int getpeername( sockaddr *name, int *len );
+    uMutex const struct sockaddr *getsockaddr();	// must cast result to sockaddr_in or sockaddr_un
+    uMutex int getsockname( struct sockaddr *name, socklen_t *len );
+    uMutex int getpeername( struct sockaddr *name, socklen_t *len );
     int send( char *buf, int len, int flags = 0, uDuration *timeout = NULL );
     int sendto( char *buf, int len, int flags = 0, uDuration *timeout = NULL );
-    int sendto( char *buf, int len, void *to, int tolen, int flags = 0, uDuration *timeout = NULL );
-    int sendmsg( const msghdr *msg, int flags = 0, uDuration *timeout = NULL );
+    int sendto( char *buf, int len, struct sockaddr *to, socklen_t tolen, int flags = 0, uDuration *timeout = NULL );
+    int sendmsg( const struct msghdr *msg, int flags = 0, uDuration *timeout = NULL );
     int recv( char *buf, int len, int flags = 0, uDuration *timeout = NULL );
     int recvfrom( char *buf, int len, int flags = 0, uDuration *timeout = NULL );
-    int recvfrom( char *buf, int len, void *from, int *fromlen, int flags = 0, uDuration *timeout = NULL );
-    int recvmsg( msghdr *msg, int flags = 0, uDuration *timeout = NULL );
+    int recvfrom( char *buf, int len, struct sockaddr *from, socklen_t *fromlen, int flags = 0, uDuration *timeout = NULL );
+    int recvmsg( struct msghdr *msg, int flags = 0, uDuration *timeout = NULL );
 }; // uSocketIO
 
 
@@ -97,28 +110,28 @@ class uSocketIO : public uFileIO {
 
 
 uMonitor uSocketServer : public uSocketIO {
-    friend class uSocketAccept;				// access: socket, me_accept, acceptor, unacceptor, ~uSocketAccept
+    friend class uSocketAccept;				// access: socket, _accept, acceptor, unacceptor, ~uSocketAccept
 
-    int acceptorCnt;
+    int acceptorCnt;					// number of simultaneous acceptors using server
     uSocket socket;					// one-to-one correspondance between server and socket
 
     uMutex void acceptor();
     uMutex void unacceptor();
-    uMutex int me_accept( void *adr, int *len );
+    int _accept( struct sockaddr *adr, socklen_t *len );
     void uCreateSocketServer1( const char *name, int type, int protocol, int backlog );
     void uCreateSocketServer2( unsigned short port, int type, int protocol, int backlog );
     void uCreateSocketServer3( unsigned short *port, int type, int protocol, int backlog );
   public:
     // AF_UNIX
     uSocketServer( const char *name, int type = SOCK_STREAM, int protocol = 0, int backlog = 10 );
-    uSocketServer( const char *name, uIOCluster &cluster, int type = SOCK_STREAM, int protocol = 0, int backlog = 10 );
     // AF_INET, local host
     uSocketServer( unsigned short port, int type = SOCK_STREAM, int protocol = 0, int backlog = 10 );
-    uSocketServer( unsigned short port, uIOCluster &cluster, int type = SOCK_STREAM, int protocol = 0, int backlog = 10 );
     uSocketServer( unsigned short *port, int type = SOCK_STREAM, int protocol = 0, int backlog = 10 );
-    uSocketServer( unsigned short *port, uIOCluster &cluster, int type = SOCK_STREAM, int protocol = 0, int backlog = 10 );
     virtual ~uSocketServer();
 
+    void uSetClient( struct sockaddr *addr, socklen_t len );
+    void uGetClient( struct sockaddr *addr, socklen_t *len );
+
     uDualEvent uFailure;
     friend uDualEvent uFailure;				// access: socket
     uDualEvent uOpenFailure;
@@ -133,19 +146,30 @@ uMonitor uSocketServer : public uSocketIO {
 //######################### uSocketAccept #########################
 
 
-class uSocketAccept : public uSocketIO {		// monitor
+uMonitor uSocketAccept : public uSocketIO {
     uSocketServer &socketserver;			// many-to-one correspondence among acceptors and server
     uIOaccess access;
+    bool openAccept;					// current open accept for socket ?
+    uDuration *timeout;
+    struct sockaddr *adr;
+    socklen_t *len;
 
     const uSocket &sock() const;
-    void uCreateSocketAcceptor( uDuration *timeout, void *adr, int *len );
+    void uCreateSocketAcceptor( uDuration *timeout, struct sockaddr *adr, socklen_t *len );
+    int _close();
   public:
-    uSocketAccept( uSocketServer &s, void *adr = NULL, int *len = NULL );
-    uSocketAccept( uSocketServer &s, uDuration *timeout, void *adr = NULL, int *len = NULL );
+    uSocketAccept( uSocketServer &s, struct sockaddr *adr = NULL, socklen_t *len = NULL );
+    uSocketAccept( uSocketServer &s, uDuration *timeout, struct sockaddr *adr = NULL, socklen_t *len = NULL );
+    uSocketAccept( uSocketServer &s, bool doAccept, struct sockaddr *adr = NULL, socklen_t *len = NULL );
+    uSocketAccept( uSocketServer &s, uDuration *timeout, bool doAccept, struct sockaddr *adr = NULL, socklen_t *len = NULL );
     virtual ~uSocketAccept();
 
+    void accept();
+    void accept( uDuration *timeout );
+    void close();
+
     uDualEvent uFailure;
-    friend uDualEvent uFailure;
+//    friend uDualEvent uFailure;
     uDualEvent uOpenFailure;
     uDualEvent uOpenTimeout;
     uDualEvent uCloseFailure;
@@ -159,30 +183,27 @@ class uSocketAccept : public uSocketIO {		// monitor
 //######################### uSocketClient #########################
 
 
-class uSocketClient : public uSocketIO {		// monitor
+uMonitor uSocketClient : public uSocketIO {
     uSocket socket;					// one-to-one correspondence between client and socket
+    char *tmpnm;					// temporary file for communicate with UNIX datagram
 
     void uCreateSocketClient1( const char *name, uDuration *timeout, int type, int protocol );
-    void uCreateSocketClient2( unsigned short port, uDuration *timeout, int type, int protocol );
-    void uCreateSocketClient3( unsigned short port, const char *name, uDuration *timeout, int type, int protocol );
+    void uCreateSocketClient2( unsigned short port, const char *name, uDuration *timeout, int type, int protocol );
   public:
     // AF_UNIX
     uSocketClient( const char *name, int type = SOCK_STREAM, int protocol = 0 );
     uSocketClient( const char *name, uDuration *timeout, int type = SOCK_STREAM, int protocol = 0 );
-    uSocketClient( const char *name, uIOCluster &cluster, int type = SOCK_STREAM, int protocol = 0 );
-    uSocketClient( const char *name, uIOCluster &cluster, uDuration *timeout, int type = SOCK_STREAM, int protocol = 0 );
     // AF_INET, local host
     uSocketClient( unsigned short port, int type = SOCK_STREAM, int protocol = 0 );
     uSocketClient( unsigned short port, uDuration *timeout, int type = SOCK_STREAM, int protocol = 0 );
-    uSocketClient( unsigned short port, uIOCluster &cluster, int type = SOCK_STREAM, int protocol = 0 );
-    uSocketClient( unsigned short port, uIOCluster &cluster, uDuration *timeout, int type = SOCK_STREAM, int protocol = 0 );
     // AF_INET, other host
     uSocketClient( unsigned short port, const char *name, int type = SOCK_STREAM, int protocol = 0 );
     uSocketClient( unsigned short port, const char *name, uDuration *timeout, int type = SOCK_STREAM, int protocol = 0 );
-    uSocketClient( unsigned short port, const char *name, uIOCluster &cluster, int type = SOCK_STREAM, int protocol = 0 );
-    uSocketClient( unsigned short port, const char *name, uIOCluster &cluster, uDuration *timeout, int type = SOCK_STREAM, int protocol = 0 );
     virtual ~uSocketClient();
 
+    void uSetServer( struct sockaddr *addr, socklen_t len );
+    void uGetServer( struct sockaddr *addr, socklen_t *len );
+
     uDualEvent uFailure;
     friend uDualEvent uFailure;
     uDualEvent uOpenFailure;
@@ -203,7 +224,7 @@ uDualEvent uSocket::uFailure : public uIOFailure {
   public:
     uFailure( const uSocket &s, const char *const msg );
     const uSocket &socket() const;
-    virtual void uDefaultTerminate() const;
+    virtual void defaultTerminate() const;
 }; // uSocket::uFailure
 
 
@@ -214,14 +235,14 @@ uDualEvent uSocket::uOpenFailure : public uSocket::uFailure {
     const int protocol;
   public:
     uOpenFailure( const uSocket &socket, const int domain, const int type, const int protocol, const char *const msg );
-    virtual void uDefaultTerminate() const;
+    virtual void defaultTerminate() const;
 }; // uSocket::uOpenFailure
 
 
 uDualEvent uSocket::uCloseFailure : public uSocket::uFailure {
   public:
     uCloseFailure( const uSocket &socket, const char *const msg );
-    virtual void uDefaultTerminate() const;
+    virtual void defaultTerminate() const;
 }; // uSocket::uCloseFailure
 
 
@@ -234,7 +255,7 @@ uDualEvent uSocketServer::uFailure : public uSocket::uFailure {
     uFailure( const uSocketServer &s, const char *const msg );
     const uSocketServer &server() const;
     int fileDescriptor() const;
-    virtual void uDefaultTerminate() const;
+    virtual void defaultTerminate() const;
 }; // uSocketServer::uFailure
 
 
@@ -249,7 +270,7 @@ uDualEvent uSocketServer::uOpenFailure : public uSocketServer::uFailure {
   public:
     uOpenFailure( const uSocketServer &server, const unsigned short port, const char *const name, int domain, int type, int protocol, int backlog, const char *const msg );
     const char *const name() const;			// return socket name, or NULL when hostname is used
-    virtual void uDefaultTerminate() const;
+    virtual void defaultTerminate() const;
 }; // uSocketServer::uOpenFailure
 
 
@@ -257,7 +278,7 @@ uDualEvent uSocketServer::uCloseFailure : public uSocketServer::uFailure {
     const int acceptorCnt;
   public:
     uCloseFailure( const uSocketServer &server, const int acceptorCnt, const char *const msg );
-    virtual void uDefaultTerminate() const;
+    virtual void defaultTerminate() const;
 }; // uSocketServer::uCloseFailure
 
 
@@ -266,19 +287,19 @@ uDualEvent uSocketServer::uReadFailure : public uSocketServer::uFailure {
     const char *buf;
     const int len;
     const int flags;
-    const void *from;
-    const int *fromlen;
+    const struct sockaddr *from;
+    const socklen_t *fromlen;
     const uDuration *timeout;
   public:
-    uReadFailure( const uSocketServer &sa, const char *buf, const int len, const int flags, const void *from, const int *fromlen, const uDuration *timeout, const char *const msg );
-    virtual void uDefaultTerminate() const;
+    uReadFailure( const uSocketServer &sa, const char *buf, const int len, const int flags, const struct sockaddr *from, const socklen_t *fromlen, const uDuration *timeout, const char *const msg );
+    virtual void defaultTerminate() const;
 }; // uSocketServer::uReadFailure
 
 
 uDualEvent uSocketServer::uReadTimeout : public uSocketServer::uReadFailure {
   public:
-    uReadTimeout( const uSocketServer &sa, const char *buf, const int len, const int flags, const void *from, const int *fromlen, const uDuration *timeout, const char *const msg );
-    virtual void uDefaultTerminate() const;
+    uReadTimeout( const uSocketServer &sa, const char *buf, const int len, const int flags, const struct sockaddr *from, const socklen_t *fromlen, const uDuration *timeout, const char *const msg );
+    virtual void defaultTerminate() const;
 }; // uSocketServer::uReadTimeout
 
 
@@ -287,19 +308,19 @@ uDualEvent uSocketServer::uWriteFailure : public uSocketServer::uFailure {
     const char *buf;
     const int len;
     const int flags;
-    const void *to;
+    const struct sockaddr *to;
     const int tolen;
     const uDuration *timeout;
   public:
-    uWriteFailure( const uSocketServer &sa, const char *buf, const int len, const int flags, const void *to, const int tolen, const uDuration *timeout, const char *const msg );
-    virtual void uDefaultTerminate() const;
+    uWriteFailure( const uSocketServer &sa, const char *buf, const int len, const int flags, const struct sockaddr *to, const int tolen, const uDuration *timeout, const char *const msg );
+    virtual void defaultTerminate() const;
 }; // uSocketServer::uWriteFailure
 
 
 uDualEvent uSocketServer::uWriteTimeout : public uSocketServer::uWriteFailure {
   public:
-    uWriteTimeout( const uSocketServer &sa, const char *buf, const int len, const int flags, const void *to, const int tolen, const uDuration *timeout, const char *const msg );
-    virtual void uDefaultTerminate() const;
+    uWriteTimeout( const uSocketServer &sa, const char *buf, const int len, const int flags, const struct sockaddr *to, const int tolen, const uDuration *timeout, const char *const msg );
+    virtual void defaultTerminate() const;
 }; // uSocketServer::uWriteTimeout
 
 
@@ -313,32 +334,32 @@ uDualEvent uSocketAccept::uFailure : public uSocket::uFailure {
     const uSocketAccept &acceptor() const;
     const uSocketServer &server() const;
     int fileDescriptor() const;
-    virtual void uDefaultTerminate() const;
+    virtual void defaultTerminate() const;
 }; // uSocketAccept::uFailure
 
 
 uDualEvent uSocketAccept::uOpenFailure : public uSocketAccept::uFailure {
   protected:
     const uDuration *timeout;
-    const void *adr;
-    const int *len;
+    const struct sockaddr *adr;
+    const socklen_t *len;
   public:
-    uOpenFailure( const uSocketAccept &acceptor, const uDuration *timeout, const void *adr, const int *len, const char *const msg );
-    virtual void uDefaultTerminate() const;
+    uOpenFailure( const uSocketAccept &acceptor, const uDuration *timeout, const struct sockaddr *adr, const socklen_t *len, const char *const msg );
+    virtual void defaultTerminate() const;
 }; // uSocketAccept::uOpenFailure
 
 
 uDualEvent uSocketAccept::uOpenTimeout : public uSocketAccept::uOpenFailure {
   public:
-    uOpenTimeout( const uSocketAccept &acceptor, const uDuration *timeout, const void *adr, const int *len, const char *const msg );
-    virtual void uDefaultTerminate() const;
+    uOpenTimeout( const uSocketAccept &acceptor, const uDuration *timeout, const struct sockaddr *adr, const socklen_t *len, const char *const msg );
+    virtual void defaultTerminate() const;
 }; // uSocketAccept::uOpenTimeout
 
 
 uDualEvent uSocketAccept::uCloseFailure : public uSocketAccept::uFailure {
   public:
     uCloseFailure( const uSocketAccept &acceptor, const char *const msg );
-    virtual void uDefaultTerminate() const;
+    virtual void defaultTerminate() const;
 }; // uSocketAccept::uCloseFailure
 
 
@@ -347,19 +368,19 @@ uDualEvent uSocketAccept::uReadFailure : public uSocketAccept::uFailure {
     const char *buf;
     const int len;
     const int flags;
-    const void *from;
-    const int *fromlen;
+    const struct sockaddr *from;
+    const socklen_t *fromlen;
     const uDuration *timeout;
   public:
-    uReadFailure( const uSocketAccept &sa, const char *buf, const int len, const int flags, const void *from, const int *fromlen, const uDuration *timeout, const char *const msg );
-    virtual void uDefaultTerminate() const;
+    uReadFailure( const uSocketAccept &sa, const char *buf, const int len, const int flags, const struct sockaddr *from, const socklen_t *fromlen, const uDuration *timeout, const char *const msg );
+    virtual void defaultTerminate() const;
 }; // uSocketAccept::uReadFailure
 
 
 uDualEvent uSocketAccept::uReadTimeout : public uSocketAccept::uReadFailure {
   public:
-    uReadTimeout( const uSocketAccept &sa, const char *buf, const int len, const int flags, const void *from, const int *fromlen, const uDuration *timeout, const char *const msg );
-    virtual void uDefaultTerminate() const;
+    uReadTimeout( const uSocketAccept &sa, const char *buf, const int len, const int flags, const struct sockaddr *from, const socklen_t *fromlen, const uDuration *timeout, const char *const msg );
+    virtual void defaultTerminate() const;
 }; // uSocketAccept::uReadTimeout
 
 
@@ -368,19 +389,19 @@ uDualEvent uSocketAccept::uWriteFailure : public uSocketAccept::uFailure {
     const char *buf;
     const int len;
     const int flags;
-    const void *to;
+    const struct sockaddr *to;
     const int tolen;
     const uDuration *timeout;
   public:
-    uWriteFailure( const uSocketAccept &sa, const char *buf, const int len, const int flags, const void *to, const int tolen, const uDuration *timeout, const char *const msg );
-    virtual void uDefaultTerminate() const;
+    uWriteFailure( const uSocketAccept &sa, const char *buf, const int len, const int flags, const struct sockaddr *to, const int tolen, const uDuration *timeout, const char *const msg );
+    virtual void defaultTerminate() const;
 }; // uSocketAccept::uWriteFailure
 
 
 uDualEvent uSocketAccept::uWriteTimeout : public uSocketAccept::uWriteFailure {
   public:
-    uWriteTimeout( const uSocketAccept &sa, const char *buf, const int len, const int flags, const void *to, const int tolen, const uDuration *timeout, const char *const msg );
-    virtual void uDefaultTerminate() const;
+    uWriteTimeout( const uSocketAccept &sa, const char *buf, const int len, const int flags, const struct sockaddr *to, const int tolen, const uDuration *timeout, const char *const msg );
+    virtual void defaultTerminate() const;
 }; // uSocketAccept::uWriteTimeout
 
 
@@ -393,7 +414,7 @@ uDualEvent uSocketClient::uFailure : public uSocket::uFailure {
     uFailure( const uSocketClient &client, const char *const msg );
     const uSocketClient &client() const;
     int fileDescriptor() const;
-    virtual void uDefaultTerminate() const;
+    virtual void defaultTerminate() const;
 }; // uSocketClient::uFailure
 
 
@@ -401,29 +422,28 @@ uDualEvent uSocketClient::uOpenFailure : public uSocketClient::uFailure {
   protected:
     unsigned short port;
     char _name[FILENAME_MAX];
-    const uIOCluster &cluster;
     const uDuration *timeout;
     const int domain;
     const int type;
     const int protocol;
   public:
-    uOpenFailure( const uSocketClient &client, const unsigned short port, const char *const name, const uIOCluster &cluster, uDuration *timeout, const int domain, const int type, const int protocol, const char *const msg );
+    uOpenFailure( const uSocketClient &client, const unsigned short port, const char *const name, uDuration *timeout, const int domain, const int type, const int protocol, const char *const msg );
     const char *const name() const;
-    virtual void uDefaultTerminate() const;
+    virtual void defaultTerminate() const;
 }; // uSocketClient::uOpenFailure
 
 
 uDualEvent uSocketClient::uOpenTimeout : public uSocketClient::uOpenFailure {
   public:
-    uOpenTimeout( const uSocketClient &client, const unsigned short port, const char *const name, const uIOCluster &cluster, uDuration *timeout, const int domain, const int type, const int protocol, const char *const msg );
-    virtual void uDefaultTerminate() const;
+    uOpenTimeout( const uSocketClient &client, const unsigned short port, const char *const name, uDuration *timeout, const int domain, const int type, const int protocol, const char *const msg );
+    virtual void defaultTerminate() const;
 }; // uSocketClient::uOpenTimeout
 
 
 uDualEvent uSocketClient::uCloseFailure : public uSocketClient::uFailure {
   public:
     uCloseFailure( const uSocketClient &acceptor, const char *const msg );
-    virtual void uDefaultTerminate() const;
+    virtual void defaultTerminate() const;
 }; // uSocketClient::uCloseFailure
 
 
@@ -432,19 +452,19 @@ uDualEvent uSocketClient::uReadFailure : public uSocketClient::uFailure {
     const char *buf;
     const int len;
     const int flags;
-    const void *from;
-    const int *fromlen;
+    const struct sockaddr *from;
+    const socklen_t *fromlen;
     const uDuration *timeout;
   public:
-    uReadFailure( const uSocketClient &sa, const char *buf, const int len, const int flags, const void *from, const int *fromlen, const uDuration *timeout, const char *const msg );
-    virtual void uDefaultTerminate() const;
+    uReadFailure( const uSocketClient &sa, const char *buf, const int len, const int flags, const struct sockaddr *from, const socklen_t *fromlen, const uDuration *timeout, const char *const msg );
+    virtual void defaultTerminate() const;
 }; // uSocketClient::uReadFailure
 
 
 uDualEvent uSocketClient::uReadTimeout : public uSocketClient::uReadFailure {
   public:
-    uReadTimeout( const uSocketClient &sa, const char *buf, const int len, const int flags, const void *from, const int *fromlen, const uDuration *timeout, const char *const msg );
-    virtual void uDefaultTerminate() const;
+    uReadTimeout( const uSocketClient &sa, const char *buf, const int len, const int flags, const struct sockaddr *from, const socklen_t *fromlen, const uDuration *timeout, const char *const msg );
+    virtual void defaultTerminate() const;
 }; // uSocketClient::uReadTimeout
 
 
@@ -453,27 +473,27 @@ uDualEvent uSocketClient::uWriteFailure : public uSocketClient::uFailure {
     const char *buf;
     const int len;
     const int flags;
-    const void *to;
+    const struct sockaddr *to;
     const int tolen;
     const uDuration *timeout;
   public:
-    uWriteFailure( const uSocketClient &sa, const char *buf, const int len, const int flags, const void *to, const int tolen, const uDuration *timeout, const char *const msg );
-    virtual void uDefaultTerminate() const;
+    uWriteFailure( const uSocketClient &sa, const char *buf, const int len, const int flags, const struct sockaddr *to, const int tolen, const uDuration *timeout, const char *const msg );
+    virtual void defaultTerminate() const;
 }; // uSocketClient::uWriteFailure
 
 
 uDualEvent uSocketClient::uWriteTimeout : public uSocketClient::uWriteFailure {
   public:
-    uWriteTimeout( const uSocketClient &sa, const char *buf, const int len, const int flags, const void *to, const int tolen, const uDuration *timeout, const char *const msg );
-    virtual void uDefaultTerminate() const;
+    uWriteTimeout( const uSocketClient &sa, const char *buf, const int len, const int flags, const struct sockaddr *to, const int tolen, const uDuration *timeout, const char *const msg );
+    virtual void defaultTerminate() const;
 }; // uSocketClient::uWriteTimeout
 
 
 #pragma __U_USER_CODE__
 
-#endif __U_SOCKET_H__
+#endif // __U_SOCKET_H__
 
 
-// Local Variables:
-// compile-command: "dmake"
-// End:
+// Local Variables: //
+// compile-command: "gmake install" //
+// End: //
