@@ -1,25 +1,39 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
 // 
 // input.c -- 
 // 
 // Author           : Richard A. Stroobosscher
 // Created On       : Tue Apr 28 15:05:28 1992
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Oct 28 10:04:20 1998
-// Update Count     : 41
+// Last Modified On : Sun Aug  8 07:32:54 2004
+// Update Count     : 55
+//
+// This  library is free  software; you  can redistribute  it and/or  modify it
+// under the terms of the GNU Lesser General Public License as published by the
+// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
+// option) any later version.
+// 
+// This library is distributed in the  hope that it will be useful, but WITHOUT
+// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
+// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
+// for more details.
+// 
+// You should  have received a  copy of the  GNU Lesser General  Public License
+// along  with this library.
 // 
-
-#include <stdlib.h>
-#include <stdio.h>
 
 #include "main.h"
 #include "hash.h"
-#include "include.h"
 #include "token.h"
 #include "input.h"
 
+#include <iostream>
+
+using std::cerr;
+using std::endl;
+
 #define BUFLEN (64 * 1024)
 
 static char buffer[BUFLEN];
@@ -28,20 +42,21 @@ static char *eptr = buffer + BUFLEN;
 static char *cptr;
 
 static int get() {
-    int c = getc( yyin );
+    char c;
+    *yyin >> c;
     if ( cptr == eptr ) {
-	fprintf( stderr, "get() : internal buffer space exhausted.\n" );
+	cerr << "get() : internal buffer space exhausted." << endl;
     } // if
     *cptr++ = c;
-    return c;
+    return yyin->eof() ? EOF : c;
 } // get
 
-static inline void unget( int c ) {
-    ungetc( c, yyin );
+static void unget( int c ) {
+    yyin->putback( c );
     cptr--;
 } // unget
 
-static inline void unwrap() {
+static void unwrap() {
     cptr = bptr;
 } // unwrap
 
@@ -92,14 +107,12 @@ typedef enum state_t {
     possible_end_comment,
 } state_t;
 
-token_t * input() {
-
+token_t *getinput() {
     state_t state = start;
 
     unwrap();
     
     for ( ;; ) {
-
 	int c = get();
 	switch ( state ) {
 	  case start:
@@ -339,7 +352,7 @@ token_t * input() {
 		return new token_t( GE, hash_table->look( buffer ) );
 	      case '?':
 		wrap();
-		return new token_t( MAX, hash_table->look( buffer ) );
+		return new token_t( GMAX, hash_table->look( buffer ) );	// g++ >? maximum
 	      default:
 		unget( c );
 		wrap();
@@ -367,7 +380,7 @@ token_t * input() {
 		return new token_t( LE, hash_table->look( buffer ) );
 	      case '?':
 		wrap();
-		return new token_t( MIN, hash_table->look( buffer ) );
+		return new token_t( GMIN, hash_table->look( buffer ) );	// g++ <? minimum
 	      default:
 		unget( c );
 		wrap();
@@ -696,20 +709,20 @@ token_t * input() {
 	    } // switch
 	    break;
 	  default:
-	    fprintf( stderr, "uC++ translator error: input(), internal error.\n" );
+	    cerr << "uC++ Translator error: getinput(), internal error." << endl;
 	    exit( -1 );
 	} // switch
     } // for
-} // input
+} // getinput
 
 void read_all_input() {
     for ( ;; ) {
-	token_t *token = input();
+	token_t *token = getinput();
 	list->add_to_tail( *token );
       if ( token->value == EOF ) break;
     } // for
 } // read_all_input
 
 // Local Variables: //
-// compile-command: "dmake" //
+// compile-command: "gmake install" //
 // End: //
