@@ -1,23 +1,28 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
 // 
 // main.h -- 
 // 
 // Author           : Richard A. Stroobosscher
 // Created On       : Tue Apr 28 16:06:46 1992
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Sep 30 14:20:26 1997
-// Update Count     : 20
+// Last Modified On : Wed Oct 16 10:54:47 2002
+// Update Count     : 26
 // 
 
 #ifndef __MAIN_H__
 #define __MAIN_H__
 
-extern FILE *yyin;
-extern FILE *yyout;
+#include <iostream>
 
-extern bool er;
+using std::istream;
+using std::ostream;
+
+extern istream *yyin;
+extern ostream *yyout;
+
+extern bool error;
 extern bool Yield;					// name "yield" already taken
 extern bool verify;
 extern bool trace;
@@ -27,8 +32,8 @@ extern bool user;
 
 int main( int argc, char *argv[] );
 
-#endif __MAIN_H__
+#endif // __MAIN_H__
 
 // Local Variables: //
-// compile-command: "dmake" //
+// compile-command: "gmake install" //
 // End: //
