@@ -1,34 +1,56 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
 // 
 // output.c -- 
 // 
 // Author           : Richard A. Stroobosscher
 // Created On       : Tue Apr 28 15:09:30 1992
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Oct 28 10:04:21 1998
-// Update Count     : 83
+// Last Modified On : Sun Aug  8 07:34:51 2004
+// Update Count     : 139
+//
+// This  library is free  software; you  can redistribute  it and/or  modify it
+// under the terms of the GNU Lesser General Public License as published by the
+// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
+// option) any later version.
+// 
+// This library is distributed in the  hope that it will be useful, but WITHOUT
+// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
+// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
+// for more details.
+// 
+// You should  have received a  copy of the  GNU Lesser General  Public License
+// along  with this library.
 // 
 
-#include <stdlib.h>
-#include <stdio.h>
-
-#include "assert.h"
+#include "uassert.h"
 #include "main.h"
 #include "key.h"
 #include "hash.h"
-#include "include.h"
 #include "token.h"
 #include "input.h"
 #include "output.h"
 
-static char * file = NULL;
+static char *file = NULL;
 static unsigned int line = 1;
 
-static inline int isdigit( char c ) {
-    return c >= '0' && c <= '9';
-} // isdigit
+void sigSegvBusHandler( int sig ) {
+    cerr << "uC++ Translator error: fatal problem during parsing." << endl <<
+	"Probable cause is mismatched braces, missing terminating quote, or use of an undeclared type name." << endl <<
+	"Possible area where problem occurred:" << endl;
+    token_t *p;
+    int i;
+    // backup 5 tokens
+    for ( i = 0, p = ahead; i < 5 && p->aft != NULL; i += 1, p = p->aft );
+    // print 10 tokens around problem area
+    for ( i = 0; i < 10 && p != NULL; i += 1, p = p->fore ) {
+      if ( p->hash == NULL ) break;
+	cerr << p->hash->text << " ";
+    } // for
+    cerr << endl;
+    exit( 0 );
+} // sigSegvBusHandler
 
 static void parse_directive( char *text ) {	
     char *c = text + 1;					// get past '#'
@@ -49,7 +71,7 @@ static void parse_directive( char *text ) {
 		c += 1;
 	    } // while
 	    *c = '\0';					// terminate the string containing the file name
-	    if ( file != NULL ) delete file;		// deallocate old string
+	    if ( file != NULL ) delete [] file;		// deallocate old string
 	    file = new char[ strlen( s ) + 1 ];		// allocate new string
 	    strcpy( file, s );				// copy the file name into this string
 	    *c = '\"';					// fill in the end quote again "
@@ -64,26 +86,27 @@ static void parse_directive( char *text ) {
 // number so that when error and warning messages appear, the exact origin of
 // those messages can be displayed.
 
-void output( token_t * token ) {
-    assert( token != NULL );
-    assert( token->hash != NULL );
-    assert( token->hash->text != NULL );
+void putoutput( token_t *token ) {
+    uassert( token != NULL );
+    uassert( token->hash != NULL );
+    uassert( token->hash->text != NULL );
 
     switch ( token->value ) {
       case '\n':
       case '\r':
 	line += 1;
-	fprintf( yyout, "%s", token->hash->text );
+	*yyout << token->hash->text;
 	break;
       case '#':
 	parse_directive( token->hash->text );
-	fprintf( yyout, "%s", token->hash->text );
+	*yyout << token->hash->text;
 	break;
       case ERROR:
-	fprintf( stderr, "%s:%d: uC++ translator error: %s\n", file, line, token->hash->text );
+	cerr << file << ":" << line << ": uC++ Translator error: " << token->hash->text << endl;
+	error = true;
 	break;
       case WARNING:
-	fprintf( stderr, "%s:%d: uC++ translator warning: %s\n", file, line, token->hash->text );
+	cerr << file << ":" << line << ": uC++ Translator warning: " << token->hash->text << endl;
 	break;
       case COROUTINE:					// do not print these keywords
       case DISABLE:
@@ -99,6 +122,8 @@ void output( token_t * token ) {
       case THROWEVENT:
 	break;
       case ACCEPT:
+      case ACCEPTRETURN:
+      case ACCEPTWAIT:
       case AT:
       case OR:
       case RAISE:
@@ -116,28 +141,29 @@ void output( token_t * token ) {
 	    // if no code or error was generated, print an error now
 	    int value = token->next_parse_token()->value;
 	    if ( value != CODE && value != ERROR ) {
-		fprintf( stderr, "%s:%d: uC++ translator error: parse error before %s\n", file, line, token->hash->text );
+		cerr << file << ":" << line << ": uC++ Translator error: parse error before " << token->hash->text << endl;
+		error = true;
 	    } // if
 	    break;
 	}
       default:
-	fprintf( yyout, " %s", token->hash->text );
+	*yyout << " " << token->hash->text;
 	break;
     } // switch
-} // output
+} // putoutput
 
-// The routine 'write_all_output' takes the stream of tokens and calls 'output'
+// The routine 'write_all_output' takes the stream of tokens and calls 'putoutput'
 // to convert them all to a stream of text.  It then deletes each token in the
 // list.
 
 void write_all_output() {
     for ( ;; ) {
-	token_t * token = list->remove_from_head();
+	token_t *token = list->remove_from_head();
       if ( token->value == EOF ) break;
-	output( token );
+	putoutput( token );
     } // for
 } // write_all_output
 
 // Local Variables: //
-// compile-command: "dmake" //
+// compile-command: "gmake install" //
 // End: //
