@@ -1,21 +1,33 @@
 //                              -*- Mode: C++ -*- 
 // 
-// uC++ Version 4.7, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
+// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
 // 
 // structor.c -- 
 // 
 // Author           : Richard A. Stroobosscher
 // Created On       : Tue Apr 28 15:17:01 1992
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Wed Dec  4 08:50:55 1996
-// Update Count     : 24
+// Last Modified On : Sun Aug  8 07:29:52 2004
+// Update Count     : 29
+//
+// This  library is free  software; you  can redistribute  it and/or  modify it
+// under the terms of the GNU Lesser General Public License as published by the
+// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
+// option) any later version.
+// 
+// This library is distributed in the  hope that it will be useful, but WITHOUT
+// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
+// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
+// for more details.
+// 
+// You should  have received a  copy of the  GNU Lesser General  Public License
+// along  with this library.
 // 
 
-#include <stdlib.h>
-#include <stdio.h>
-
 #include "structor.h"
 
+#include <cstddef>					// size_t
+
 structor_t::structor_t() {
     prefix = NULL;
     suffix = NULL;
@@ -55,5 +67,5 @@ int structor_list_t::empty_structor_list() {
 
 
 // Local Variables: //
-// compile-command: "dmake" //
+// compile-command: "gmake install" //
 // End: //
